/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 *   ===========================================================================
 */
#include <stdio.h>
#include <constants.h>
#include <aif_setup.h>
#include <fsync_setup.h>
#include <edma_setup.h>
#include <intc_setup.h>
#include <csl_psc.h>


/****** Global variable declarations ***********/

// global chip count keeps track of # of chips DMA'ed to UL DSP buffer
Int32 gChipCount = 0;

// UPlink L2 RAM Memory
#pragma DATA_SECTION (agUlCircBuff, ".extData_sect");
Uint32 agUlCircBuff[TOTAL_SIZE_INBOUND_DATA_BUFFER_IN_CHIPS_2];

//DOWNLINK L2 RAM Memory
#pragma DATA_SECTION (agDlCircBuff, ".extData_sect");
Uint32 agDlCircBuff[TOTAL_SIZE_INBOUND_DATA_BUFFER_IN_CHIPS];
#pragma DATA_SECTION (agDlCircBuff1, ".extData_sect");
Uint32 agDlCircBuff1[TOTAL_SIZE_INBOUND_DATA_BUFFER_IN_CHIPS];

static Uint32 tempVar = 0;

/***** Global function declarations ************/
void enableAIF();


/***** Local fn declarations **************/

static void DoCleanup();
static void DoCompare();

/**** Local fn definitions ****************/


/*********************************************************
 * Radio Buffer setup
 * configure buffers for storing inbound link data
 *
 ********************************************************/

static void DoRadioBufferSetup()
{
   Uint32 i,j;
   static Uint32 k=0;
   // Init Data
   for (i= 0;i < TOTAL_SIZE_INBOUND_DATA_BUFFER_IN_CHIPS_2; i++)
   {
      agUlCircBuff[i] = 0x0;
   }

   for (i=0;i < (TOTAL_SIZE_INBOUND_DATA_BUFFER_IN_CHIPS/2560); i++)
     {
        for (j=0;j<2560;j++)
        {
        agDlCircBuff[k] = j;
		  agDlCircBuff1[k] = j;
        k++;
        }       
     }
   

}



/*********************************************************
 * Clean up actions
 *
 ********************************************************/
static void DoCleanup(void)
{

   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_DISABLE_TIMER, NULL);

   CSL_fsyncClose(hFsync);

   CSL_edma3ChannelClose(hEdmaChannel[EDMA_CH_AIF_DSP_CS_LINK_0]);
   CSL_edma3ChannelClose(hEdmaChannel[EDMA_CH_DSP_AIF_CS_LINK_0]);

   CSL_edma3Close(hEdmaModule);

   CSL_aifClose(hAifLink[0]);
   CSL_aifClose(hAifLink[1]);
   CSL_aifClose(hAifLink[2]);

}

/*********************************************************
 * Clean up actions
 *
 ********************************************************/
static void DoCompare(void)
{
    Uint32 count,x=0,y;
    Uint32 numMismatch[2]= {0,0};
    y=16;
    //printf("Starting comparsison of Rx CS data with reference data \n");

    // compare CS data with reference
    for (count=0; count < TOTAL_SIZE_INBOUND_DATA_BUFFER_IN_CHIPS; count++)
    {
	    if((count!=0) && (count%16 ==0))
	    {
	    	y=y+16;
			x=x+16;
	   }
        if ((agUlCircBuff[x+count] != agDlCircBuff[count])&&
		      (agUlCircBuff[y+count] != agDlCircBuff1[count]))
        {
            numMismatch[0]++;
            //printf("Mismatch at line %d of CS data \n",count); each line of UL data contains 2 chips
        }
    }



    // print final report
    if (numMismatch[0] == 0) {

        printf("Test case passed - Rx data matches CS  reference data \n");
    }
    else
    {
        printf("Test case failed - Rx data does not match at %d places with Link0 ref data\n", numMismatch[0]);
        printf("Test case failed - Rx data does not match at %d places with Link1 ref data\n", numMismatch[0]);
    }



}

/* PUBLIC FUNCTIONS **********************************************************/

/*********************************************************
 * Edma Isr
 * Isr triggered every 8 chips after completion of edma x'fer of 8 chips
 * the tcc int can be disabled on the cpu, this isr is for debug only
 ********************************************************/

interrupt void edma_tcc_ISR()
{
   CSL_Edma3CmdIntr intrQuery;

  	
	
   	tempVar++;


   intrQuery.region = CSL_EDMA3_REGION_GLOBAL;
   // query status of EDMA pendng interrupt register
   CSL_edma3GetHwStatus(hEdmaModule,CSL_EDMA3_QUERY_INTRPEND,(void *)&intrQuery);

   // clear IPR bit
   CSL_edma3HwControl(hEdmaModule,CSL_EDMA3_CMD_INTRPEND_CLEAR,(void *)&intrQuery);

	while ((intrQuery.intr != 0) || (intrQuery.intrh != 0)) {

   // clear IPR bit

   CSL_edma3HwControl(hEdmaModule,CSL_EDMA3_CMD_INTRPEND_CLEAR,(void *)&intrQuery);   


   if (intrQuery.intr & (1 << (EDMA_TCC_AIF_DSP_CS_LINK_0& 31)))
   {
      // AI->UL DSP x'fer complete
      gChipCount += NUM_CHIPS_PER_FRAME;

          
      // check if end of test
      if (gChipCount == LENGTH_TEST_RUN_IN_CHIPS )
      {
         DoCleanup();

         DoCompare();

         exit(1);
      }
   }
   if (intrQuery.intrh & (Uint32)(1<<(EDMA_TCC_DSP_AIF_CS_LINK_0 & 31)))
   {
      // UL DSP -> Ext mem x'fer complete

   }
   if (intrQuery.intrh & (Uint32)(1 << (EDMA_TCC_AIF_PSFIFO_0_DSP & 31)))
   {
      // PS fifo 0 x'fer complete

   }
   
    if (intrQuery.intrh & (Uint32)(1 << (EDMA_TCC_DSP_AIF_PSFIFO_0 & 31)))
   {
      // PS fifo 0 x'fer complete

   }
   else
   {
     // assert(0); //unexpected tcc
   }
   CSL_edma3GetHwStatus(hEdmaModule,CSL_EDMA3_QUERY_INTRPEND,(void *)&intrQuery);

} // close while loop
}
/******************************************************
 * Aif FSync Isr
 * Isr triggered every 38400 chips from FSync event FS_EVT1
 * All event gen are enabled after 1st AIF fsync tick is rcvd
 * This ensures all DMA's are in sync with AIF activity
 *
 ********************************************************/
interrupt void aif_fsevt1_ISR()
{
}


/*********************************************************
 * EDMA FSync Isr
 * Isr triggered every 8 chips from FSync event FS_EVT4 
 * the fs evt4 can be disabled on the cpu, this isr is for debug only

 ********************************************************/
interrupt void fsevt4_ISR()
{

}

/*********************************************************
 * EDMA FSync Isr
 * Isr triggered every 8 chips from FSync event FS_EVT5
 * the fs evt4 can be disabled on the cpu, this isr is for debug only
 ********************************************************/
interrupt void fsevt5_ISR()
{

}


/*********************************/

int main()
{   
	Uint16 * mem_ptr = (Uint16*) 0x02A0080C;
   
   	enableAIF();

   	for (mem_ptr = (Uint16*)(0x02A0080C);  mem_ptr < (Uint16*)(0x02a0082C); mem_ptr++) *(mem_ptr) = 0xFFF0;


   	// setup radio buffer located in DDR with intialized radio data in AIF format   
   	DoRadioBufferSetup();

   	// Setup Edma
   	vConfigEdma();

   	//Setup Aif
   	vConfigAif();
   
   	// Interrupts Setup
   	vConfigIntc();

   	// FSync setup
   	vConfigFsync();

   	// Setup timer for UMTS sync
   	timer_doTest();

   	printf("Testcase running...\n");

	// After everything's done sit in interruptable while loop
	// while not servicing an interrupt.
   	while(1)    
   	{
    	asm(" NOP 5 " ); 
    	asm(" NOP 5 " ); 
   	}        
}


void enableAIF()
{
	CSL_PscObj pscObj;
	CSL_PscHandle hPsc;
	CSL_Status status;
	CSL_PscPowerDomain pwrDmn = CSL_PSC_PWRDMN_PROXYA;
	CSL_PscPeripherals module = CSL_PSC_MODULE_AIF;
	CSL_PscPwrDmnTransState response;

	memset(&pscObj, 0, sizeof(CSL_PscObj));      

    /* Init PSC module */
	CSL_pscInit(NULL);

    /* Open PSC module to get a Handle */
	hPsc = CSL_pscOpen(&pscObj, CSL_PSC, NULL, &status);

    /* Enable power domain for AIF */
	CSL_pscHwControl(hPsc, CSL_PSC_CMD_ENABLE_PWRDMN, &pwrDmn);
    /* Enable clock for the specified module AIF */
	CSL_pscHwControl(hPsc, CSL_PSC_CMD_ENABLE_MODULE, &module);
	/*Enable AIF Power domain GO transition */
	CSL_pscHwControl(hPsc, CSL_PSC_CMD_PWRDMN_TRNS, &pwrDmn);

 	response.pwrDmn = CSL_PSC_PWRDMN_PROXYA;
    response.status = 0x0; 
	do{
    	CSL_pscGetHwStatus(hPsc, CSL_PSC_QUERY_PWRDMN_TRANS_STAT, (void *)&response);
		(response.status) &= (1 << CSL_PSC_PWRDMN_PROXYA);
	}while((response.status) != 0x0);

    /* Close the PSC module */
	CSL_pscClose(hPsc);
}

