/* =============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * =============================================================================
 */
/* *****************************************************************************
 *
 * DESCRIPTION:    Contains code for Fsync setup
 *
 * *****************************************************************************
 */

/* STANDARD INCLUDES ********************************************************/


/* PROJECT INCLUDES *********************************************************/

#include "fsync_setup.h"

//#include "val_util.h"

/* MACROS *******************************************************************/


/* GLOBAL VARIABLE DEFINITIONS **********************************************/

// handle for Fsync
CSL_FsyncHandle hFsync;
//  Fsync object
CSL_FsyncObj myFsyncObj;


/* PRIVATE TYPES DEFINITIONS ************************************************/

/* PRIVATE VARIABLE DEFINITIONS *********************************************/


/* PRIVATE FUNCTION PROTOTYPES **********************************************/



/* PRIVATE FUNCTION DEFINITIONS *********************************************/




/* PUBLIC FUNCTIONS **********************************************************/

/******************************************************************************
*
*  Function          : vConfigFsync
*
*  Parameters        : None
*
*  Returns           : None
*
*  Description       :                       
*
******************************************************************************/
void vConfigFsync(void)
{
   // Fsync setup 
   CSL_FsyncSetup myFsyncCfg;
   
   // terminal count setup 
   Uint16 terminalChipCount;
   CSL_FsyncTimerTermCountObj rp3TerminalCount, sysTerminalCount;
   CSL_FsyncTimerCountObj timerInit;
   
   // CSL status
   CSL_Status status;

   // ctrl arg for Hw command
   CSL_BitMask16 ctrlArg;
   
   // configuration obj for mask based trigger gen 
   CSL_FsyncMaskTriggerGenObj configMaskTrigger[FSYNC_NUM_ACTIVE_MASK_EVEN_GEN];

   // configuration obj for counter based trigger gen 
   CSL_FsyncCounterTriggerGenObj configCounterTrigger[FSYNC_NUM_ACTIVE_COUNTER_EVEN_GEN];

   // event gen used
   CSL_FsyncTriggerGenNum eventGenUsed;
   
   /* configure terminal count */
   terminalChipCount = CHIP_COUNT_WRAP_WCDMA_FDD;//15
    
   //rp3TerminalCount.lastFrameNum  = FRAME_COUNT_WRAP_WCDMA_FDD;
   rp3TerminalCount.lastSlotNum   = SLOT_COUNT_WRAP_WCDMA_FDD; //9
   rp3TerminalCount.lastSampleNum = SAMPLE_COUNT_WRAP_WCDMA_FDD;
   rp3TerminalCount.numChipTerminalCount = NUM_CHIP_COUNT_WRAP_WCDMA_FDD;
   rp3TerminalCount.pLastChipNum = &terminalChipCount;

   // sys timer not used, so set all fields to zero 
   sysTerminalCount.lastSlotNum   = 0;
   sysTerminalCount.lastSampleNum = 0;
   sysTerminalCount.numChipTerminalCount = 0,
   sysTerminalCount.pLastChipNum = NULL;
   
   /* Do config Fsync with non-RP1 interface, in this example UMTS_SYNC/UMTS_CLK drive the FSync */
   myFsyncCfg.syncRP3Timer = CSL_FSYNC_UMTS_SYNC;//CSL_FSYNC_FRAME_BURST;
   myFsyncCfg.syncSystemTimer = CSL_FSYNC_UMTS_SYNC;
   myFsyncCfg.clkRP3Timer = CSL_FSYNC_FRAME_SYNC_CLK;//CSL_FSYNC_UMTS_CLK;
   myFsyncCfg.clkSystemTimer = CSL_FSYNC_FRAME_SYNC_CLK;//CSL_FSYNC_UMTS_CLK;
   myFsyncCfg.pTerminalCountRP3Timer = &rp3TerminalCount;
   myFsyncCfg.pTerminalCountSystemTimer = &sysTerminalCount;
   myFsyncCfg.systemTimerRp1Sync = CSL_FSYNC_RP1_TYPE_NOT_USED;
   myFsyncCfg.rp3SyncDelay = 0;
   myFsyncCfg.systemSyncDelay = 0;
   myFsyncCfg.todSyncDelay = 0;
   myFsyncCfg.rp3EqualsSysTimer = FALSE;
   myFsyncCfg.syncMode = CSL_FSYNC_NON_RP1_SYNC_MODE;
   myFsyncCfg.reSyncMode = CSL_FSYNC_NO_AUTO_RESYNC_MODE;
   myFsyncCfg.crcUsage = CSL_FSYNC_USE_SYNC_BURST_ON_CRC_FAIL; // this field is don't care since FSync is in non-RP1 mode
   myFsyncCfg.crcPosition = CSL_FSYNC_CRC_BIT_16_RCVD_FIRST; // this field is don't care since FSync is in non-RP1 mode
   myFsyncCfg.todLeapUsage = CSL_FSYNC_DONT_ADD_LEAPSECS; // this field is don't care since FSync is in non-RP1 mode
   
   // watchdog timer is not set since we are using non-RP1 mode
   myFsyncCfg.setupWatchDog.rp3FrameUpdateRate   = 0; 
   myFsyncCfg.setupWatchDog.wcdmaFrameUpdateRate = 0; 
   myFsyncCfg.setupWatchDog.todFrameUpdateRate   = 0;

   timerInit.frameNum = 0;
   timerInit.slotNum = 0;
   //timerInit.chipTerminalIndex =0;
   timerInit.chipNum = 0;
   //timerInit.sampleNum = 0;
   
   // Init RP3 timer value
   myFsyncCfg.timerInit.pRp3TimerInit = &timerInit;          
   // Init system timer value
   myFsyncCfg.timerInit.pSystemTimerInit = &timerInit;         
   
   /** configure mask basd trigger event to occur every frame(10msecs), event for AIF frame sync
    * events occurs 0,38400,... */
   configMaskTrigger[0].timerUsed = CSL_FSYNC_RP3_TIMER;
   configMaskTrigger[0].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_1;
   configMaskTrigger[0].mask.frameMask = 0;
   configMaskTrigger[0].mask.slotMask = 0xFF;
   configMaskTrigger[0].mask.chipTerminalCountIndexMask = 0;
   configMaskTrigger[0].mask.chipMask = 0xFFFF;
   configMaskTrigger[0].mask.sampleMask = 0xFF;
   
  // configMaskTrigger[0].offset.frameOffset = 0; // don't care field
   configMaskTrigger[0].offset.slotOffset = 0;
   configMaskTrigger[0].offset.chipTerminalCountIndex = 0;
   configMaskTrigger[0].offset.chipOffset = 0;
   configMaskTrigger[0].offset.sampleOffset = 0;
   
   configMaskTrigger[0].compareValue.slotValue = 0;
   configMaskTrigger[0].compareValue.chipTerminalCountIndexValue = 0;  // don't care
   configMaskTrigger[0].compareValue.chipValue = 0;
   configMaskTrigger[0].compareValue.sampleValue = 0;

   /** configure mask based trigger event to occur every 4 chips for EDMA x'fer (AIF inbound RAM -> UL DSP)
    * events occur 13,17,21..*/
   configMaskTrigger[1].timerUsed = CSL_FSYNC_RP3_TIMER;
   configMaskTrigger[1].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_4;
   configMaskTrigger[1].mask.frameMask = 0;
   configMaskTrigger[1].mask.slotMask = 0;
   configMaskTrigger[1].mask.chipTerminalCountIndexMask = 0;
   configMaskTrigger[1].mask.chipMask = 0x3;
   configMaskTrigger[1].mask.sampleMask = 0xFF;
   
//   configMaskTrigger[1].offset.frameOffset = 0; // don't care field         
   configMaskTrigger[1].offset.slotOffset = 0;     
   configMaskTrigger[1].offset.chipTerminalCountIndex = 0;                  
   configMaskTrigger[1].offset.chipOffset = 12;      
   configMaskTrigger[1].offset.sampleOffset = 0;  
   
   configMaskTrigger[1].compareValue.slotValue = 0;
   configMaskTrigger[1].compareValue.chipTerminalCountIndexValue = 0;  // don't care
   configMaskTrigger[1].compareValue.chipValue = 1;
   configMaskTrigger[1].compareValue.sampleValue = 0;

   /** configure mask basd trigger event gen 18-23 to occur every 4 chips, AIF x'fer done strobes 
    * events occurs 1,5,9 .. */

   // event gen 18 config
   configMaskTrigger[2].timerUsed = CSL_FSYNC_RP3_TIMER;
   configMaskTrigger[2].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_18;
   configMaskTrigger[2].mask.frameMask = 0;
   configMaskTrigger[2].mask.slotMask = 0;
   configMaskTrigger[2].mask.chipTerminalCountIndexMask = 0;
   configMaskTrigger[2].mask.chipMask = 0x3;
   configMaskTrigger[2].mask.sampleMask = 0xFF;
   
 //  configMaskTrigger[2].offset.frameOffset = 0; // don't care field         
   configMaskTrigger[2].offset.slotOffset = 0;      
   configMaskTrigger[2].offset.chipTerminalCountIndex = 0;                  
   configMaskTrigger[2].offset.chipOffset = 3;      
   configMaskTrigger[2].offset.sampleOffset = 0;  
   
   configMaskTrigger[2].compareValue.slotValue = 0;
   configMaskTrigger[2].compareValue.chipTerminalCountIndexValue = 0;  // don't care
   configMaskTrigger[2].compareValue.chipValue = 1;
   configMaskTrigger[2].compareValue.sampleValue = 0;
   
    //event gen 24 config
   configMaskTrigger[3].timerUsed = CSL_FSYNC_RP3_TIMER;
   configMaskTrigger[3].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_24;
   configMaskTrigger[3].mask.frameMask = 0;
   configMaskTrigger[3].mask.slotMask = 0xFF;
   configMaskTrigger[3].mask.chipTerminalCountIndexMask = 0;
   configMaskTrigger[3].mask.chipMask = 0xFFFF;
   configMaskTrigger[3].mask.sampleMask = 0xFF;
   
//   configMaskTrigger[3].offset.frameOffset = 0; // don't care field
   configMaskTrigger[3].offset.slotOffset = 0;
   configMaskTrigger[3].offset.chipTerminalCountIndex = 0;
   configMaskTrigger[3].offset.chipOffset = 3;
   configMaskTrigger[3].offset.sampleOffset = 0;
   
   configMaskTrigger[3].compareValue.slotValue = 0;
   configMaskTrigger[3].compareValue.chipTerminalCountIndexValue = 0;  // don't care
   configMaskTrigger[3].compareValue.chipValue = 2;
   configMaskTrigger[3].compareValue.sampleValue = 0;

   // event gen 5
   /** configure mask based trigger event to occur every 4 chips for EDMA x'fer (DSP -> AIF outbound RAM)
    * events occur 0,4,8..*/
   configMaskTrigger[4].timerUsed = CSL_FSYNC_RP3_TIMER;
   configMaskTrigger[4].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_5;
   configMaskTrigger[4].mask.frameMask = 0;
   configMaskTrigger[4].mask.slotMask = 0;
   configMaskTrigger[4].mask.chipTerminalCountIndexMask = 0;
   configMaskTrigger[4].mask.chipMask = 0x3;
   configMaskTrigger[4].mask.sampleMask = 0xFF;
   
   // lag of 8 chips between AIF write and EDMA read
  // configMaskTrigger[4].offset.frameOffset = 0; // don't care field         
   configMaskTrigger[4].offset.slotOffset = 0;     
   configMaskTrigger[4].offset.chipTerminalCountIndex = 0;                  
   configMaskTrigger[4].offset.chipOffset = 0;      
   configMaskTrigger[4].offset.sampleOffset = 0;  
   
   configMaskTrigger[4].compareValue.slotValue = 0;
   configMaskTrigger[4].compareValue.chipTerminalCountIndexValue = 0;  // don't care
   configMaskTrigger[4].compareValue.chipValue = 0;
   configMaskTrigger[4].compareValue.sampleValue = 0;

   /** configure mask basd trigger event gen 18-23 to occur every 4 chips, AIF x'fer done strobes 
    * events occurs 1,5,9 .. */
   /** configure mask basd trigger event gen 18-23 to occur every 4 chips, AIF x'fer done strobes 
    * events occurs 1,5,9 .. */

   // event gen 18 config
   configMaskTrigger[6].timerUsed = CSL_FSYNC_RP3_TIMER;
   configMaskTrigger[6].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_19;
   configMaskTrigger[6].mask.frameMask = 0;
   configMaskTrigger[6].mask.slotMask = 0;
   configMaskTrigger[6].mask.chipTerminalCountIndexMask = 0;
   configMaskTrigger[6].mask.chipMask = 0x3;
   configMaskTrigger[6].mask.sampleMask = 0xFF;
   
  // configMaskTrigger[6].offset.frameOffset = 0; // don't care field         
   configMaskTrigger[6].offset.slotOffset = 0;      
   configMaskTrigger[6].offset.chipTerminalCountIndex = 0;                  
   configMaskTrigger[6].offset.chipOffset = 3;      
   configMaskTrigger[6].offset.sampleOffset = 0;  
   
   configMaskTrigger[6].compareValue.slotValue = 0;
   configMaskTrigger[6].compareValue.chipTerminalCountIndexValue = 0;  // don't care
   configMaskTrigger[6].compareValue.chipValue = 1;
   configMaskTrigger[6].compareValue.sampleValue = 0;
   
    //event gen 24 config
   configMaskTrigger[7].timerUsed = CSL_FSYNC_RP3_TIMER;
   configMaskTrigger[7].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_25;
   configMaskTrigger[7].mask.frameMask = 0;
   configMaskTrigger[7].mask.slotMask = 0xFF;
   configMaskTrigger[7].mask.chipTerminalCountIndexMask = 0;
   configMaskTrigger[7].mask.chipMask = 0xFFFF;
   configMaskTrigger[7].mask.sampleMask = 0xFF;
   
 //  configMaskTrigger[7].offset.frameOffset = 0; // don't care field
   configMaskTrigger[7].offset.slotOffset = 0;
   configMaskTrigger[7].offset.chipTerminalCountIndex = 0;
   configMaskTrigger[7].offset.chipOffset = 3;
   configMaskTrigger[7].offset.sampleOffset = 0;
   
   configMaskTrigger[7].compareValue.slotValue = 0;
   configMaskTrigger[7].compareValue.chipTerminalCountIndexValue = 0;  // don't care
   configMaskTrigger[7].compareValue.chipValue = 2;
   configMaskTrigger[7].compareValue.sampleValue = 0;

   // event gen 5
   /** configure mask based trigger event to occur every 4 chips for EDMA x'fer (DSP -> AIF outbound RAM)
    * events occur 0,4,8..*/
   configMaskTrigger[5].timerUsed = CSL_FSYNC_RP3_TIMER;
   configMaskTrigger[5].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_7;
   configMaskTrigger[5].mask.frameMask = 0;
   configMaskTrigger[5].mask.slotMask = 0;
   configMaskTrigger[5].mask.chipTerminalCountIndexMask = 0;
   configMaskTrigger[5].mask.chipMask = 0x3;
   configMaskTrigger[5].mask.sampleMask = 0xFF;
   
   // lag of 8 chips between AIF write and EDMA read
 //  configMaskTrigger[5].offset.frameOffset = 0; // don't care field         
   configMaskTrigger[5].offset.slotOffset = 0;     
   configMaskTrigger[5].offset.chipTerminalCountIndex = 0;                  
   configMaskTrigger[5].offset.chipOffset = 0;      
   configMaskTrigger[5].offset.sampleOffset = 0;  
   
   configMaskTrigger[5].compareValue.slotValue = 0;
   configMaskTrigger[5].compareValue.chipTerminalCountIndexValue = 0;  // don't care
   configMaskTrigger[5].compareValue.chipValue = 0;
   configMaskTrigger[5].compareValue.sampleValue = 0;

   

   // event gen 10
   /** configure mask basd trigger event to occur every 20 chips for EDMA x'fer (ExtMem -> AIF PS FIFO 0)
    * events occur 5,25,45..*/
   configCounterTrigger[0].timerUsed = CSL_FSYNC_RP3_TIMER;
   configCounterTrigger[0].eventGenUsed = CSL_FSYNC_TRIGGER_GEN_10;
   configCounterTrigger[0].eventCount = 4*(SAMPLE_COUNT_WRAP_WCDMA_FDD+1);

   configCounterTrigger[0].offset.slotOffset = 0;
   configCounterTrigger[0].offset.chipTerminalCountIndex = 0;
   configCounterTrigger[0].offset.chipOffset = 2;
   configCounterTrigger[0].offset.sampleOffset = 0; 

/* Initialize CSL library, this step is required */
   CSL_fsyncInit(NULL);

   /* Open handle for link 0 - for use */
   hFsync = CSL_fsyncOpen(&myFsyncObj, CSL_FSYNC, NULL, &status);

   if ((hFsync == NULL) || (status != CSL_SOK)) 
   {
      printf ("\nError opening CSL_FSYNC");
      exit(1);
   }                                                          

   // Do setup for Fsync
   CSL_fsyncHwSetup(hFsync, &myFsyncCfg);

   // configure mask based trigger generator 1
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_MASK_BASED_TRIGGER_GEN, (void *)&configMaskTrigger[0]);
   // configure mask based trigger generator 4
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_MASK_BASED_TRIGGER_GEN, (void *)&configMaskTrigger[1]);
   // configure mask based trigger generator 18,24,5
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_MASK_BASED_TRIGGER_GEN, (void *)&configMaskTrigger[2]);
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_MASK_BASED_TRIGGER_GEN, (void *)&configMaskTrigger[3]);
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_MASK_BASED_TRIGGER_GEN, (void *)&configMaskTrigger[4]);
     CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_MASK_BASED_TRIGGER_GEN, (void *)&configMaskTrigger[5]);
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_MASK_BASED_TRIGGER_GEN, (void *)&configMaskTrigger[6]);
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_MASK_BASED_TRIGGER_GEN, (void *)&configMaskTrigger[7]);
  
   // configure counter based trigger generator 10
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_COUNTER_BASED_TRIGGER_GEN, (void *)&configCounterTrigger[0]);

   // Enable trigger generator 1
   eventGenUsed = CSL_FSYNC_TRIGGER_GEN_1; //0
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)&eventGenUsed);
   
   // Enable trig gen 4
   eventGenUsed = CSL_FSYNC_TRIGGER_GEN_4;  //1                                             
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)(&eventGenUsed));

   eventGenUsed = CSL_FSYNC_TRIGGER_GEN_5;//14
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)(&eventGenUsed));

   eventGenUsed = CSL_FSYNC_TRIGGER_GEN_18; //2
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)(&eventGenUsed));
   
   // Enable trig gen 24
   eventGenUsed = CSL_FSYNC_TRIGGER_GEN_24; //8
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)&eventGenUsed);
   
   eventGenUsed = CSL_FSYNC_TRIGGER_GEN_7;//14
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)(&eventGenUsed));

   eventGenUsed = CSL_FSYNC_TRIGGER_GEN_19; //2
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)(&eventGenUsed));
   
   // Enable trig gen 24
   eventGenUsed = CSL_FSYNC_TRIGGER_GEN_25; //8
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)&eventGenUsed);// Enable trig gen 19

 /*  eventGenUsed = CSL_FSYNC_TRIGGER_GEN_10;
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)(&eventGenUsed)); 
*/
   // Enable timer 
   ctrlArg = 0;// this is a don't care value for timer enable
   
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TIMER, &ctrlArg);
   
  //enableTBMMCR();
  //writeTBMMCR(0xD00F0000, 0x00000200);
   //testVal = readTBMMCR(0xD00F0000);
   //VAL_TRACE(12340000);

//   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_TRIGGER_SYSTEM_TEST_SYNC, NULL); 
   
}

/*(C) Texas Instruments 2005 */
