/* =============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * =============================================================================
 */
/****************************************************************************
 *
 * DESCRIPTION:    Contains code for aif setup
 *
 ****************************************************************************/

/* STANDARD INCLUDES ********************************************************/


/* PROJECT INCLUDES *********************************************************/

#include "aif_setup.h"

/* MACROS *******************************************************************/


/* GLOBAL VARIABLE DEFINITIONS **********************************************/

// Aif link objects
CSL_AifLinkObj AifObj[AIF_NUM_ACTIVE_LINKS];

// handle for links
CSL_AifHandle hAifLink[AIF_NUM_ACTIVE_LINKS];


/* PRIVATE TYPES DEFINITIONS ************************************************/

/* PRIVATE VARIABLE DEFINITIONS *********************************************/


/* PRIVATE FUNCTION PROTOTYPES **********************************************/



/* PRIVATE FUNCTION DEFINITIONS *********************************************/




/* PUBLIC FUNCTIONS **********************************************************/

/******************************************************************************
*
*  Function          : vConfigAif
*
*  Parameters        : None
*
*  Returns           : None
*
*  Description       : 
*                      
******************************************************************************/

void vConfigAif(void)
{
   // Aif pointer to context
   CSL_AifContext AifContext;
   //AIF module specific parameters
   CSL_AifParam  aifParam;
   // CSL status
   CSL_Status status;
   // Ctrl Argument;
   Uint16 ctrlArg;
   /* Setup for links */
   CSL_AifLinkSetup aConfigLink[AIF_NUM_ACTIVE_LINKS];
   // global config for AIF */
   CSL_AifGlobalSetup gblCfg;
   // Setup for common params for links 
   CSL_AifCommonLinkSetup aCommoncfg[AIF_NUM_ACTIVE_LINKS];
   // Setup for inbound links
   CSL_AifInboundLinkSetup aInboundCfg[AIF_NUM_ACTIVE_LINKS];
   // Setup for outbound links
   CSL_AifOutboundLinkSetup aOutboundCfg[AIF_NUM_ACTIVE_LINKS];
   // Setup for Pd for inbound links 
   CSL_AifPdSetup aPdCfg[AIF_NUM_ACTIVE_LINKS];
   // Rx Mac setup for inbound links
   CSL_AifRxMacSetup aRmCfg[AIF_NUM_ACTIVE_LINKS];
   // Tx Mac setup for outbound links
   CSL_AifTxMacSetup aTmCfg[AIF_NUM_ACTIVE_LINKS];
   // Protocol encoder setup for outbound links
   CSL_AifPeSetup aPeCfg[AIF_NUM_ACTIVE_LINKS];
   // Aggegator setup for outbound links
   CSL_AifAggregatorSetup aAgCfg[AIF_NUM_ACTIVE_LINKS];
   // Serdes setup
   CSL_AifSerdesSetup aSdCfg[AIF_NUM_ACTIVE_LINKS];
   // Pd setup for all links
   CSL_AifPdCommonSetup pdCommonCfg;
   // Rx MAC setup for all links
   CSL_AifRxMacCommonSetup rmCommonCfg;
   // Serdes common setup
   CSL_AifSerdesCommonSetup sdCommonCfg;
   // Ps FIFO for all links
   CSL_AifInboundFifoSetup psInFifoCfg;
   // Type field LUT
   Uint8 aTypeFieldLut[AIF_NUM_TYPE_FIELD_ENTRIES] = AIF_TYPE_FIELD_LUT;
   // Inbound AxC Address field LUT
   Uint16 aAxCAddrLut[AIF_NUM_ACTIVE_LINKS][AIF_NUM_ACTIVE_AXS_INBND_LINK_0]= {AIF_AXC_ADDR_IN_LUT_LINK_0};
   // Inbound PS FIFO Addr LUT
   Uint16 aPsAddrLut[AIF_NUM_ACTIVE_INBND_PS_FIFOS][AIF_MAX_SIZE_INBND_PS_ADDR_FIFO] = 
       {AIF_PS_ADDR_LUT_FIFO_0};
   // Outbound AxC Addr field LUT
   Uint16 aAxCAddrOutLut[AIF_NUM_ACTIVE_LINKS][CSL_AIF_MAX_NUM_CS_TRANSMISSION_RULES]=
       {AIF_AXC_ADDR_OUT_LUT_LINK_0};
   // Outbound AxC Mask
   Uint16 aAxCOutMask[AIF_NUM_ACTIVE_LINKS][CSL_AIF_MAX_NUM_CS_TRANSMISSION_RULES] = 
       {AIF_AXC_OUT_MASK_LINK_0};
   // Outbound AxC Compare
   Uint16 aAxCOutCompare[AIF_NUM_ACTIVE_LINKS][CSL_AIF_MAX_NUM_CS_TRANSMISSION_RULES] =
       {AIF_AXC_OUT_COMP_LINK_0};
   // Outbound AxC Aggregator Ctrl
   Uint8 aAxCAggrCtrlLut[AIF_NUM_ACTIVE_LINKS][CSL_AIF_MAX_NUM_CS_TRANSMISSION_RULES] = 
       {AIF_AXC_OUT_AGGRCTRL_LINK_0};
   // Outbound Ctrl terminal count
   Uint16 aCtrlTCount[AIF_NUM_ACTIVE_LINKS][CSL_AIF_MAX_NUM_CONTROL_TRANSMISSION_RULES] = 
       {AIF_CTRL_TCOUNT_LINK_0};
   // Outbound Ctrl compare
   Uint16 aCtrlCmp[AIF_NUM_ACTIVE_LINKS][CSL_AIF_MAX_NUM_CONTROL_TRANSMISSION_RULES] = 
       {AIF_CTRL_COMPARE_LINK_0};
   // Outbound Ctrl src select
   CSL_AifOutboundFifoIndex aCtrlSrcSel[AIF_NUM_ACTIVE_LINKS][CSL_AIF_MAX_NUM_CONTROL_TRANSMISSION_RULES] = 
       {AIF_CTRL_SRC_SEL_LINK_0};
   // Outbound Ctrl data Aggr. Ctrl
   Uint8 aCtrlAggrCtrlLut[AIF_NUM_ACTIVE_LINKS][CSL_AIF_MAX_NUM_CONTROL_TRANSMISSION_RULES] =
       {AIF_CTRL_OUT_AGGRCTRL_LINK_0};
   #ifdef CPRI
   Uint16 aAxCCpriSiLut[CSL_AIF_CPRI_MAX_NUM_AXC_PER_4X_LINK_7_15_BIT] = AIF_CPRI_SI_AXC_LUT;

   CSL_AifCpriTxMacSetup cpriMacSetup = CPRI_MAC_SETUP;
   #endif

   // counter
   Uint8 i;
   
   
   
   /* Initialize CSL library, this step is required */
   CSL_aifInit(&AifContext);

   aifParam.linkIndex = CSL_AIF_LINK_1;
   
   /* Open handle for link 0 - for use */
   hAifLink[0] = CSL_aifOpen(&AifObj[0], CSL_AIF, &aifParam, &status);

   if ((hAifLink[0] == NULL) || (status != CSL_SOK)) 
   {
      printf ("\nError opening CSL_AIF");
      exit(1);
   }

   aConfigLink[0].globalSetup = &gblCfg;
   aConfigLink[0].commonlinkSetup = &aCommoncfg[0];
   aConfigLink[0].inboundlinkSetup = &aInboundCfg[0];
   aConfigLink[0].outboundlinkSetup = &aOutboundCfg[0];

   // populate global config fields
   #ifdef CPRI
   gblCfg.linkProtocol = CSL_AIF_LINK_PROTOCOL_CPRI;
   #else
   gblCfg.linkProtocol = CSL_AIF_LINK_PROTOCOL_OBSAI;
   #endif
   gblCfg.pCdSetup = NULL;  // don't setup for now
   gblCfg.pInboundPsFifoSetup = &psInFifoCfg;

   //populate common fields
   aCommoncfg[0].linkIndex = CSL_AIF_LINK_1;
#if LINK_RATE == 4
   aCommoncfg[0].linkRate = CSL_AIF_LINK_RATE_4x;
#elif LINK_RATE == 2
   aCommoncfg[0].linkRate = CSL_AIF_LINK_RATE_2x;
#elif LINK_RATE == 1
   aCommoncfg[0].linkRate = CSL_AIF_LINK_RATE_1x;
#endif

   aCommoncfg[0].pSerdesSetup = &aSdCfg[0]; // unpopulated for now

   // populate inbound fields for link 0
   aInboundCfg[0].antDataWidth = CSL_AIF_DATA_WIDTH_15_BIT;
   aInboundCfg[0].linkDataType = CSL_AIF_LINK_DATA_TYPE_DL;
   aInboundCfg[0].numActiveAxC = AIF_NUM_ACTIVE_AXS_INBND_LINK_0;
   aInboundCfg[0].pRxMacSetup = &aRmCfg[0];
   aInboundCfg[0].pPdSetup = &aPdCfg[0];

   // populate outbound fields for link 0
   aOutboundCfg[0].antDataWidth = CSL_AIF_DATA_WIDTH_15_BIT;
   aOutboundCfg[0].linkDataType = CSL_AIF_LINK_DATA_TYPE_DL;
   aOutboundCfg[0].numActiveAxC = AIF_NUM_ACTIVE_AXS_OUTBND_LINK_0;
   aOutboundCfg[0].pTxMacSetup = &aTmCfg[0];
   aOutboundCfg[0].pPeSetup = &aPeCfg[0];
   aOutboundCfg[0].pAggrSetup = &aAgCfg[0];
   aOutboundCfg[0].fifoEnBitMask = AIF_DB_OUT_FIFO_ENABLE_MASK_LINK_0;

   // PD common cfg
   pdCommonCfg.addressMask = 0x3FF;
   pdCommonCfg.numTypeFieldEntries = AIF_NUM_TYPE_FIELD_ENTRIES;
   pdCommonCfg.pInboundTypeFieldLut = aTypeFieldLut;
   pdCommonCfg.sizeInboundPsAddrFieldLut[0] = AIF_SIZE_INBND_PS_ADDR_FIFO_0;
   pdCommonCfg.sizeInboundPsAddrFieldLut[1] = AIF_SIZE_INBND_PS_ADDR_FIFO_1;
   pdCommonCfg.sizeInboundPsAddrFieldLut[2] = AIF_SIZE_INBND_PS_ADDR_FIFO_2;
   pdCommonCfg.sizeInboundPsAddrFieldLut[3] = AIF_SIZE_INBND_PS_ADDR_FIFO_3;
   pdCommonCfg.pInboundPsAddrFieldLut[0] = &aPsAddrLut[0][0];
   pdCommonCfg.pInboundPsAddrFieldLut[1] = NULL;
   pdCommonCfg.pInboundPsAddrFieldLut[2] = NULL;
   pdCommonCfg.pInboundPsAddrFieldLut[3] = NULL;

   // RM common cfg
   rmCommonCfg.frameSyncT     = AIF_RM_FRAME_SYNC_THRESH;
   rmCommonCfg.frameUnSyncT   = AIF_RM_FRAME_UNSYNC_THRESH;
   rmCommonCfg.syncT          = AIF_RM_SYNC_THRESH;
   rmCommonCfg.unSyncT        = AIF_RM_UNSYNC_THRESH;

   // SD common cfg
   sdCommonCfg.bEnablePll = TRUE;
   sdCommonCfg.pllMpyFactor = CSL_AIF_PLL_MUL_FACTOR_20X;  // multiply factor 20

   // Inbound PS fifo cfg
   psInFifoCfg.eventDepth[0] = AIF_EVTDEPTH_INBND_PS_FIFO_0;
   psInFifoCfg.eventDepth[1] = AIF_EVTDEPTH_INBND_PS_FIFO_1;
   psInFifoCfg.eventDepth[2] = AIF_EVTDEPTH_INBND_PS_FIFO_2;
   psInFifoCfg.eventDepth[3] = AIF_EVTDEPTH_INBND_PS_FIFO_3;
   psInFifoCfg.sizeFifo[0]   = AIF_SIZE_INBND_FIFO_0;
   psInFifoCfg.sizeFifo[1]   = AIF_SIZE_INBND_FIFO_1;
   psInFifoCfg.sizeFifo[2]   = AIF_SIZE_INBND_FIFO_2;
   psInFifoCfg.sizeFifo[3]   = AIF_SIZE_INBND_FIFO_3;

   // populate PD link fields
   aPdCfg[0].bEnablePd = TRUE;
   aPdCfg[0].bCpriCtrlWordCapture = FALSE;
   aPdCfg[0].pPdCommonSetup = &pdCommonCfg; 
   aPdCfg[0].sizeInboundAxCAddrFieldLut = AIF_NUM_ACTIVE_AXS_INBND_LINK_0;
   aPdCfg[0].pInboundAxCAddrFieldLut = &(aAxCAddrLut[0][0]);
   
    
   // populate Rx MAC link fields
   aRmCfg[0].bEnableRxMac = TRUE;
   aRmCfg[0].losDetThreshold = AIF_RM_LOS_DETECT_THREH;//255
   aRmCfg[0].maxMasterFrameOffset = AIF_RM_MAX_MASTER_FRAME_OFFSET;//200
   aRmCfg[0].piOffset = AIF_RM_PI_OFFSET;//200
   aRmCfg[0].pRxMacCommonSetup = &rmCommonCfg; 
   aRmCfg[0].validMasterFrameOffset = AIF_RM_VALID_MASTER_FRAME_OFFSET;//200

  // populate SD link fields
   aSdCfg[0].bEnableRxAlign = TRUE;
   aSdCfg[0].bEnableRxLos = FALSE;
   aSdCfg[0].pCommonSetup = &sdCommonCfg;
   aSdCfg[0].rxCdrAlgorithm = (CSL_AifSerdesRxCdrAlg)0;
   aSdCfg[0].rxEqualizerConfig = CSL_AIF_SERDES_RX_EQ_ADAPTIVE;
   aSdCfg[0].rxPairPolarity = (CSL_AifSerdesRxPairPolarity)0;
   aSdCfg[0].rxTermination = (CSL_AifSerdesRxTerm)0;
   aSdCfg[0].txAmpConfig = CSL_AIF_SERDES_TX_AMP_CONFIG_750;
   aSdCfg[0].txCommonMode = (CSL_AifSerdesTxCommonMode)0;
   aSdCfg[0].txDeEmphasisConfig =CSL_AIF_SERDES_TX_DE_CONFIG_8;
   aSdCfg[0].txPairPolarity = (CSL_AifSerdesTxPairPolarity)0;

   // populate Tx MAC link fields
   aTmCfg[0].bEnableTxMac = TRUE;
   aTmCfg[0].bEnableRxLos = FALSE;
   aTmCfg[0].bEnableFrameXmit = TRUE;
   aTmCfg[0].deltaOffset = AIF_TM_DELTA_OFFSET;//50
   aTmCfg[0].pCpriTxMacSetup = NULL;
   aTmCfg[0].threshTxMacFifo = AIF_TM_FIFO_THRESH;

   // populate PE link fields
   aPeCfg[0].bEnablePe = TRUE;
   aPeCfg[0].cpriCtrlWordMode = CSL_AIF_CPRI_CTRL_WORD_READ_FROM_RAM; // don't care for obsai mode
   aPeCfg[0].obsaiAxCType = AIF_PE_AXC_TYPE_OUTBOUND;

   #ifdef CPRI
   aTmCfg[0].pCpriTxMacSetup = &cpriMacSetup;
   aPdCfg[0].pInboundCpriSiAxCLut = aAxCCpriSiLut;
   #endif

   for (i=0; i < CSL_AIF_MAX_NUM_CS_TRANSMISSION_RULES; i++ ) 
   {
      aPeCfg[0].aAxCAddressFieldLut[i] = aAxCAddrOutLut[0][i];
      aPeCfg[0].aAxCMask[i] = aAxCOutMask[0][i];
      aPeCfg[0].aAxCCompare[i] = aAxCOutCompare[0][i];
      aPeCfg[0].aAggrCtrlAxCLut[i] = aAxCAggrCtrlLut[0][i];
   }

   for (i=0; i < CSL_AIF_MAX_NUM_CONTROL_TRANSMISSION_RULES; i++ ) 
   {
      aPeCfg[0].aCtrlDataTCount[i] = aCtrlTCount[0][i];
      aPeCfg[0].aCtrlDataCompare[i] = aCtrlCmp[0][i];
      aPeCfg[0].aCtrlDataSrcSel[i] = aCtrlSrcSel[0][i];
      aPeCfg[0].aAggrCtrlCtrlDataLut[i] = aCtrlAggrCtrlLut[0][i];
   }
   
   aPeCfg[0].psDataMask = AIF_PE_PS_DATA_MASK;
   aPeCfg[0].psDataCompare = AIF_PE_PS_DATA_COMPARE;
   aPeCfg[0].psDataSrcSel = AIF_PE_PS_DATA_SRC_SEL;
   aPeCfg[0].aggrCtrlPsData = AIF_PE_PS_DATA_AGGR_CTRL;

   aAgCfg[0].aggrMode = CSL_AIF_AGGR_MODE_PE_IP_ONLY;
   aAgCfg[0].bEnableAggrErr = TRUE;

   //Do setup for link - 0
   CSL_aifHwSetup(hAifLink[0], &aConfigLink[0]);


#ifdef SHORT_FRAME_MODE
   hAifLink[0]->regs->AI_GLOBAL_CFG |= 0x00000100;
#endif  

   /****** ENABLE SERDES LOOPBACK ************/
#ifdef ENABLE_SERDES_LOOPBACK
   // enable SERDES on links 0-3 i.e outbound links redirected to inbound 
   hAifLink[0]->regs->AI_SERDES0_TST_CFG = SERDES_LOOPBACK_MODE;

   // enable SERDES on links 4-5 i.e outbound links redirected to inbound 
   hAifLink[0]->regs->AI_SERDES1_TST_CFG = SERDES_LOOPBACK_MODE;

   //hAifLink[0]->regs->LCFG[0].LINK_CFG=0x34404013;
   hAifLink[0]->regs->LCFG[1].LINK_CFG |= 0x30000000;
#endif
   ///////////////////////////
#ifdef DISABLE_K28_7_ALIGNMENT_REPORTING
   hAifLink[0]->regs->RM_LINK[1].RM_LINK_CFG |= 0x10; //Suppresses the K28.7 alignment 
                                                      //error reporting
#endif

  #ifdef CPRI
   hAifLink[0]->regs->AI_GLOBAL_CFG = 0x00000101;
  #endif

    // Enable Tx/Rx of link 0
   ctrlArg = (Uint32)TRUE;
    
   CSL_aifHwControl(hAifLink[0], CSL_AIF_CMD_ENABLE_DISABLE_RX_LINK, (void *)&ctrlArg);

   CSL_aifHwControl(hAifLink[0], CSL_AIF_CMD_ENABLE_DISABLE_TX_LINK, (void *)&ctrlArg);
}

/*(C) Texas Instruments 2005 */

