/* =============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * =============================================================================
 */
/* *****************************************************************************
 *
 * DESCRIPTION:    Contains code for Intc
 *
 * *****************************************************************************
 */

/* STANDARD INCLUDES ********************************************************/


/* PROJECT INCLUDES *********************************************************/

#include "intc_setup.h"

/* MACROS *******************************************************************/


/* GLOBAL VARIABLE DEFINITIONS **********************************************/
CSL_IntcObj    intcObj[NUM_CPU_EVENTS];
CSL_IntcHandle hIntc[NUM_CPU_EVENTS];

CSL_IntcEventHandlerRecord Record[13];
CSL_IntcGlobalEnableState state;


/* PRIVATE TYPES DEFINITIONS ************************************************/

/* PRIVATE VARIABLE DEFINITIONS *********************************************/


/* PRIVATE FUNCTION PROTOTYPES **********************************************/



/* PRIVATE FUNCTION DEFINITIONS *********************************************/




/* PUBLIC FUNCTIONS **********************************************************/

/******************************************************************************
*
*  Function          : Initialise Demodulator
*
*  Parameters        : None
*
*  Returns           : None
*
*  Description       : 1. Register Demodulator processes
*                      2. Initialise Demodulator
*
******************************************************************************/
void vConfigIntc(void)
{
   CSL_IntcParam vectId[13];
   CSL_IntcContext context;
   
   /* Setup the global Interrupt */
   context.numEvtEntries = 13;    
   context.eventhandlerRecord = Record; 
   CSL_intcInit(&context);
   /* Enable NMIs  */
   CSL_intcGlobalNmiEnable();
   /* Enable Global Interrupts  */
   CSL_intcGlobalEnable(&state);
   
   /* VectorID for the Global Edma Event  */
   vectId[CPU_EVT_EDMA_TCC] = CSL_INTC_VECTID_4;
   /* VectorID for the  AIF FSync Interrupt Event */ 
   vectId[CPU_EVT_FS_1] = CSL_INTC_VECTID_5;
   /* VectorID for the  FS Evt 4 strobe */ 
   vectId[CPU_EVT_FS_4] = CSL_INTC_VECTID_6;
   vectId[3] = CSL_INTC_VECTID_7;
   
   /* Opening a handle for the Global EDMA Event */
   hIntc[CPU_EVT_EDMA_TCC]  = CSL_intcOpen(&intcObj[CPU_EVT_EDMA_TCC],
                                            CSL_INTC_EVENTID_EDMA3CC_GINT, // EDMA Global Completion Intr 
                                            &vectId[CPU_EVT_EDMA_TCC],
                                            NULL);
   
   /* Opening a handle for the AIf frame sync Interrupt Event */                                      
   hIntc[CPU_EVT_FS_1]   = CSL_intcOpen(&intcObj[CPU_EVT_FS_1],
                                         CSL_INTC_EVENTID_FSEVT1, // AIF FSync Intr Event  FS_EVT1
                                         &vectId[CPU_EVT_FS_1],
                                         NULL);

   /* Opening a handle for the Fsync->EDMA Interrupt Event */                                      
   hIntc[CPU_EVT_FS_4]   = CSL_intcOpen(&intcObj[CPU_EVT_FS_4],
                                         CSL_INTC_EVENTID_FSEVT4, // FSync Intr Event  FS_EVT4
                                         &vectId[CPU_EVT_FS_4],
                                         NULL);

   hIntc[3]   = CSL_intcOpen(&intcObj[3],
                                         CSL_INTC_EVENTID_FSEVT6, // FSync Intr Event  FS_EVT4
                                         &vectId[3],
                                         NULL);


   //Hook the ISRs
   CSL_intcHookIsr(vectId[CPU_EVT_EDMA_TCC],&edma_tcc_ISR);
   CSL_intcHookIsr(vectId[CPU_EVT_FS_1],    &aif_fsevt1_ISR);
   CSL_intcHookIsr(vectId[CPU_EVT_FS_4],    &fsevt4_ISR);
   CSL_intcHookIsr(vectId[3], &fsevt5_ISR);
           
   // Clear the Interrupt    
   CSL_intcHwControl(hIntc[CPU_EVT_EDMA_TCC], CSL_INTC_CMD_EVTCLEAR, NULL);
   CSL_intcHwControl(hIntc[CPU_EVT_FS_1], CSL_INTC_CMD_EVTCLEAR,  NULL);
   CSL_intcHwControl(hIntc[CPU_EVT_FS_4], CSL_INTC_CMD_EVTCLEAR,  NULL);
   CSL_intcHwControl(hIntc[3], CSL_INTC_CMD_EVTCLEAR,  NULL);
     
    //Enable the Event & the interrupt 
   CSL_intcHwControl(hIntc[CPU_EVT_EDMA_TCC], CSL_INTC_CMD_EVTENABLE, NULL);
   CSL_intcHwControl(hIntc[CPU_EVT_FS_1], CSL_INTC_CMD_EVTENABLE,  NULL);     
   CSL_intcHwControl(hIntc[CPU_EVT_FS_4], CSL_INTC_CMD_EVTENABLE,  NULL);
   CSL_intcHwControl(hIntc[3], CSL_INTC_CMD_EVTENABLE,  NULL);
   
}


/*(C) Texas Instruments 2005 */
