/* =============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * =============================================================================
 */
/* *****************************************************************************
 *
 * DESCRIPTION:    Contains code for Edma setup
 *
 * *****************************************************************************
 */

/* STANDARD INCLUDES ********************************************************/


/* PROJECT INCLUDES *********************************************************/

#include "edma_setup.h"

/* MACROS *******************************************************************/


/* GLOBAL VARIABLE DEFINITIONS **********************************************/

CSL_Edma3Handle    hEdmaModule;
CSL_Edma3Obj       edmaObj;
// Edma Ch object
CSL_Edma3ChannelObj ChObj[NUM_EDMA_CHANNELS];
// EDMA Ch handle
CSL_Edma3ChannelHandle hEdmaChannel[NUM_EDMA_CHANNELS];

// buffer
extern Uint32 agUlCircBuff[TOTAL_SIZE_INBOUND_DATA_BUFFER_IN_CHIPS];// div by 2 because each 32 bit contains 2 chips

extern Uint32 agDlCircBuff[TOTAL_SIZE_INBOUND_DATA_BUFFER_IN_CHIPS]; // each 32 bit contains 1 chip of DL data

extern Uint32 *dlPtr;


extern far Uint32 agDSPInbndPsBuff[SIZE_INBND_PS_BUFFER_IN_WORDS];

extern far Uint32 agDSPOutbndPsBuff[SIZE_OUTBND_PS_BUFFER_IN_WORDS];

/* PRIVATE TYPES DEFINITIONS ************************************************/

/* PRIVATE VARIABLE DEFINITIONS *********************************************/


/* PRIVATE FUNCTION PROTOTYPES **********************************************/



/* PRIVATE FUNCTION DEFINITIONS *********************************************/




/* PUBLIC FUNCTIONS **********************************************************/

/******************************************************************************
*
*  Function          : vConfigEdma
*
*  Parameters        : None
*
*  Returns           : None
*
*  Description       : 1. 
*                      2. 
*
******************************************************************************/
void vConfigEdma(void)
{
   CSL_Edma3HwSetup hwSetup;
   CSL_Edma3ParamHandle hActiveParam,hReloadParam;
   CSL_Edma3ParamSetup myParamSetup;
   CSL_Edma3Context    Edmacontext;
   CSL_Edma3ChannelAttr  chAttr;
   CSL_Edma3CmdIntr  intrEn;

   CSL_Edma3HwDmaChannelSetup  dmahwSetup[CSL_EDMA3_NUM_DMACH] = \
                                           CSL_EDMA3_DMACHANNELSETUP_DEFAULT;
   CSL_Edma3HwQdmaChannelSetup qdmahwSetup[CSL_EDMA3_NUM_QDMACH] = \
                                           CSL_EDMA3_QDMACHANNELSETUP_DEFAULT;
   
   CSL_Status chStatus;
   
   // Module Initialization
   CSL_edma3Init(&Edmacontext);
   
   // Module Level Open 
   hEdmaModule = CSL_edma3Open(&edmaObj,CSL_EDMA3,NULL,&chStatus); 
   
   if (chStatus != CSL_SOK)
      {
         printf("EDMA OPEN FAILURE");
      }
      
   /* Module Setup */
   hwSetup.dmaChaSetup  = &dmahwSetup[0];
   hwSetup.qdmaChaSetup = &qdmahwSetup[0];
   CSL_edma3HwSetup(hEdmaModule, &hwSetup);

   // Channel Open 

   chAttr.regionNum = CSL_EDMA3_REGION_GLOBAL;
   chAttr.chaNum = EDMA_CH_AIF_DSP_CS_LINK_0;
   hEdmaChannel[EDMA_CH_HNDL_AIF_DSP_CS_LINK_0] = CSL_edma3ChannelOpen(&ChObj[EDMA_CH_HNDL_AIF_DSP_CS_LINK_0],
                                                              CSL_EDMA3,
                                                              &chAttr,                            
                                                              &chStatus);  
                                                              
   CSL_edma3HwChannelSetupQue(hEdmaChannel[EDMA_CH_HNDL_DSP_AIF_CS_LINK_0],CSL_EDMA3_QUE_3);    
   // Channel Setup 
   CSL_edma3HwChannelSetupParam(hEdmaChannel[EDMA_CH_HNDL_AIF_DSP_CS_LINK_0],EDMA_PARAM_AIF_DSP_CS_LINK_0);
   
   /* Basic Setup */
   hActiveParam = CSL_edma3GetParamHandle(hEdmaChannel[EDMA_CH_HNDL_AIF_DSP_CS_LINK_0],EDMA_PARAM_AIF_DSP_CS_LINK_0,NULL);

   hReloadParam = CSL_edma3GetParamHandle(hEdmaChannel[EDMA_CH_HNDL_AIF_DSP_CS_LINK_0],EDMA_PARAM_AIF_DSP_CS_LINK_0_RELOAD,NULL);
    // Setup the parameter Entry parameters (Ping buffer)
   // intermediate and final transfer completion interrupts are enabled for debug purposes 3 and 4 param is option
   
   myParamSetup.option = CSL_EDMA3_OPT_MAKE(FALSE,FALSE,FALSE,TRUE,CSL_EDMA3_CHA_FSEVT4,CSL_EDMA3_TCC_NORMAL,CSL_EDMA3_FIFOWIDTH_NONE,FALSE,CSL_EDMA3_SYNC_AB,CSL_EDMA3_ADDRMODE_INCR,CSL_EDMA3_ADDRMODE_INCR);           
   myParamSetup.srcAddr = (Uint32)CSL_AIF_0_DATA;         
   myParamSetup.aCntbCnt = CSL_EDMA3_CNT_MAKE(A_CNT_AIF_ULDSP_XFER, B_CNT_AIF_ULDSP_XFER);
   myParamSetup.dstAddr = (Uint32)agUlCircBuff;        
   myParamSetup.srcDstBidx = CSL_EDMA3_BIDX_MAKE(SBIDX_AIF_ULDSP_XFER, DBIDX_AIF_ULDSP_XFER);      
   myParamSetup.linkBcntrld = CSL_EDMA3_LINKBCNTRLD_MAKE(hReloadParam,0);
   myParamSetup.srcDstCidx = CSL_EDMA3_CIDX_MAKE(SCIDX_AIF_ULDSP_XFER, DCIDX_AIF_ULDSP_XFER);          
   myParamSetup.cCnt = C_CNT_AIF_ULDSP_XFER;
   CSL_edma3ParamSetup(hActiveParam,&myParamSetup);
   
   
   /* Reload Setup */
   CSL_edma3ParamSetup(hReloadParam,&myParamSetup);
    
   // Enable Channel EER
   CSL_edma3HwChannelControl(hEdmaChannel[EDMA_CH_HNDL_AIF_DSP_CS_LINK_0],CSL_EDMA3_CMD_CHANNEL_ENABLE,NULL);  

   // Enable IER for intr for x'fer completion
   intrEn.region = CSL_EDMA3_REGION_GLOBAL; 
   intrEn.intr  = (Uint32)(1 << (EDMA_TCC_AIF_DSP_CS_LINK_0));
   intrEn.intrh = 0x0; 
   CSL_edma3HwControl(hEdmaModule,CSL_EDMA3_CMD_INTR_ENABLE,&intrEn);
   
   
  /**** Channel setup for DSP -> AIF for CS x'fer of DL data Link 0 ************/
   
   chAttr.regionNum = CSL_EDMA3_REGION_GLOBAL;
   chAttr.chaNum = CSL_EDMA3_CHA_FSEVT5;
   hEdmaChannel[EDMA_CH_HNDL_DSP_AIF_CS_LINK_0] = CSL_edma3ChannelOpen(&ChObj[EDMA_CH_HNDL_DSP_AIF_CS_LINK_0],
                                                                       CSL_EDMA3,
                                                                       &chAttr,                            
                                                                       &chStatus);   
   
   CSL_edma3HwChannelSetupQue(hEdmaChannel[EDMA_CH_HNDL_DSP_AIF_CS_LINK_0],CSL_EDMA3_QUE_4);
   // Channel Setup 
   CSL_edma3HwChannelSetupParam(hEdmaChannel[EDMA_CH_HNDL_DSP_AIF_CS_LINK_0],
                                EDMA_PARAM_DSP_AIF_CS_LINK_0);
   
   hActiveParam = CSL_edma3GetParamHandle(hEdmaChannel[EDMA_CH_HNDL_DSP_AIF_CS_LINK_0],
                                          EDMA_PARAM_DSP_AIF_CS_LINK_0,NULL);

   hReloadParam = CSL_edma3GetParamHandle(hEdmaChannel[EDMA_CH_HNDL_DSP_AIF_CS_LINK_0],
                                          EDMA_PARAM_DSP_AIF_CS_LINK_0_RELOAD,NULL);
   
   myParamSetup.option = CSL_EDMA3_OPT_MAKE(FALSE,FALSE,FALSE,FALSE,CSL_EDMA3_CHA_FSEVT5,
                                            CSL_EDMA3_TCC_NORMAL,CSL_EDMA3_FIFOWIDTH_NONE,FALSE,
                                            CSL_EDMA3_SYNC_AB,CSL_EDMA3_ADDRMODE_INCR,CSL_EDMA3_ADDRMODE_INCR);           
   
   myParamSetup.srcAddr = (Uint32)agDlCircBuff;         
   myParamSetup.aCntbCnt = CSL_EDMA3_CNT_MAKE(A_CNT_DSP_AIF_XFER, B_CNT_DSP_AIF_XFER);
   myParamSetup.dstAddr = (Uint32)AIF_OUTBOUND_CS_RAM_LINK_0;        
   myParamSetup.srcDstBidx = CSL_EDMA3_BIDX_MAKE(SBIDX_DSP_AIF_XFER, DBIDX_DSP_AIF_XFER);      
   myParamSetup.linkBcntrld = CSL_EDMA3_LINKBCNTRLD_MAKE(hReloadParam,0);
   myParamSetup.srcDstCidx = CSL_EDMA3_CIDX_MAKE(SCIDX_DSP_AIF_XFER, DCIDX_DSP_AIF_XFER);          
   myParamSetup.cCnt = C_CNT_DSP_AIF_XFER;
   CSL_edma3ParamSetup(hActiveParam,&myParamSetup);
   
   /* Reload Setup */
   CSL_edma3ParamSetup(hReloadParam,&myParamSetup);
    
   // Enable Channel EER
   CSL_edma3HwChannelControl(hEdmaChannel[EDMA_CH_HNDL_DSP_AIF_CS_LINK_0],CSL_EDMA3_CMD_CHANNEL_ENABLE,NULL);  

   // Enable IER for intr for x'fer completion
   intrEn.region = CSL_EDMA3_REGION_GLOBAL; 
   intrEn.intr  = 1 << (EDMA_TCC_DSP_AIF_CS_LINK_0);
   intrEn.intrh = 0x0; 
   CSL_edma3HwControl(hEdmaModule,CSL_EDMA3_CMD_INTR_ENABLE,&intrEn);

/**** Channel setup for DSP -> AIF for CS x'fer of DL data Link 1 ************/
   
   chAttr.regionNum = CSL_EDMA3_REGION_GLOBAL;
   chAttr.chaNum = CSL_EDMA3_CHA_FSEVT7;
   hEdmaChannel[EDMA_CH_DSP_AIF_CS_LINK_CHAIN_0] = CSL_edma3ChannelOpen(&ChObj[EDMA_CH_DSP_AIF_CS_LINK_CHAIN_0],
                                                                       CSL_EDMA3,
                                                                       &chAttr,                            
                                                                       &chStatus);   
   
   CSL_edma3HwChannelSetupQue(hEdmaChannel[EDMA_CH_DSP_AIF_CS_LINK_CHAIN_0],CSL_EDMA3_QUE_5);
   // Channel Setup 
   CSL_edma3HwChannelSetupParam(hEdmaChannel[EDMA_CH_DSP_AIF_CS_LINK_CHAIN_0],
                                EDMA_PARAM_DSP_AIF_CS_LINK_CHAIN_0);
   
   hActiveParam = CSL_edma3GetParamHandle(hEdmaChannel[EDMA_CH_DSP_AIF_CS_LINK_CHAIN_0],
                                          EDMA_PARAM_DSP_AIF_CS_LINK_CHAIN_0,NULL);

   hReloadParam = CSL_edma3GetParamHandle(hEdmaChannel[EDMA_CH_DSP_AIF_CS_LINK_CHAIN_0],
                                          EDMA_PARAM_DSP_AIF_CS_LINK_CHAIN_0_RELOAD,NULL);
   
   myParamSetup.option = CSL_EDMA3_OPT_MAKE(FALSE,FALSE,FALSE,FALSE,CSL_EDMA3_CHA_FSEVT7,
                                            CSL_EDMA3_TCC_NORMAL,CSL_EDMA3_FIFOWIDTH_NONE,FALSE,
                                            CSL_EDMA3_SYNC_AB,CSL_EDMA3_ADDRMODE_INCR,CSL_EDMA3_ADDRMODE_INCR);           
   
   myParamSetup.srcAddr = (Uint32)(dlPtr+512);         
   myParamSetup.aCntbCnt = CSL_EDMA3_CNT_MAKE(A_CNT_DSP_AIF_XFER, B_CNT_DSP_AIF_XFER);
   myParamSetup.dstAddr = (Uint32)AIF_OUTBOUND_CS_RAM_LINK_01;        
   myParamSetup.srcDstBidx = CSL_EDMA3_BIDX_MAKE(SBIDX_DSP_AIF_XFER, DBIDX_DSP_AIF_XFER);      
   myParamSetup.linkBcntrld = CSL_EDMA3_LINKBCNTRLD_MAKE(hReloadParam,0);
   myParamSetup.srcDstCidx = CSL_EDMA3_CIDX_MAKE(SCIDX_DSP_AIF_XFER, DCIDX_DSP_AIF_XFER);          
   myParamSetup.cCnt = C_CNT_DSP_AIF_XFER;
   CSL_edma3ParamSetup(hActiveParam,&myParamSetup);
   
   /* Reload Setup */
   CSL_edma3ParamSetup(hReloadParam,&myParamSetup);
    
   // Enable Channel EER
   CSL_edma3HwChannelControl(hEdmaChannel[EDMA_CH_DSP_AIF_CS_LINK_CHAIN_0],CSL_EDMA3_CMD_CHANNEL_ENABLE,NULL);  

   // Enable IER for intr for x'fer completion
   intrEn.region = CSL_EDMA3_REGION_GLOBAL; 
   intrEn.intr  = 1 << (CSL_EDMA3_CHA_FSEVT7);
   intrEn.intrh = 0x0; 
   CSL_edma3HwControl(hEdmaModule,CSL_EDMA3_CMD_INTR_ENABLE,&intrEn);
 }


/*(C) Texas Instruments 2005 */

















