/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */
 
/*  ============================================================================
 *  lnk.cmd   v5.00                                                         
 *         
 *    Usage:  lnk6x <obj files...>    -o <out file> -m <map file> lnk.cmd   
 *            cl6x  <src files...> -z -o <out file> -m <map file> lnk.cmd   
 *                                                                          
 *    Description: This file is a sample linker command file that can be    
 *                 used for linking programs built with the C compiler and  
 *                 running the resulting .out file on a C620x/C670x         
 *                 simulator.  Use it as a guideline.  You will want to     
 *                 change the memory layout to match your specific C6xxx    
 *                 target system.  You may want to change the allocation    
 *                 scheme according to the size of your program.            
 *                                                                          
 *    Notes: (1)   You must specivy a directory in which rts6x00.lib is     
 *                 located.  either add a -i"<directory>" line to this      
 *                 file or use the system environment variable C_DIR to     
 *                 specify a search path for the libraries.                 
 *                                                                          
 *           (2)   If the run-time library you are using is not named       
 *                 rts6200[e].lib, rts6400[e].lib, or rts6700[e].lib, be    
 *                 sure to use the correct name here.                       
 *                                                                          
 *  ============================================================================
 */

-x
-c
-heap 8192
-stack 8192
/* -e int00 */

MEMORY
{
  INVALID:     origin = 0x00000000 length = 0x00002000
  BOOT_MEM:    origin = 0x00800000 length = 0x00001000 /* This address is used for no boot mode */

  L1P_MEM:     origin = 0x00E00000 length = 0x00004000 /* This is the non-cache SRAM */

  L1D_MEM:     origin = 0x00F00000 length = 0x00004000 /* This is the non-cache SRAM */

  MAIL_BOX_MEM: origin =0x00801000 length = 0x00000100 /* L2 RAM dedicated for mail_box section so that the host testcase knows what address to refer to. */
  ETB_RAM_MEM : origin =0x00801100 length = 0x00001000 /* L2 RAM dedicated for etb_ram_data section so that the host testcase knows what address to refer to. */
  L2_MEM:      origin = 0x00810000 length = 0x00085f00 /* This is for local SRAM, could be used as cache. */
}

SECTIONS
{
/* common section */
    .vectors        		>   BOOT_MEM
    .cinit			>	L2_MEM
    .text			>	L2_MEM
    .stack			>	L2_MEM
    .bss			>	L2_MEM
    .const			>	L2_MEM
    .data			>	L2_MEM
    .far			>	L2_MEM
    .switch			>	L2_MEM
    .tables			>	L2_MEM
    .cio			> 	L2_MEM
    .sysmem                     >       L2_MEM

/* custom section used by on_trace_1.c, cross_trig.c and sl2_swbp.c */
    .mail_box			>   	MAIL_BOX_MEM

/* custom section used by on_trace_1.c */
    .etb_ram_data		> ETB_RAM_MEM 
}                             
