/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *
 *   @file  fsync_counter_evt_gen.c
 *
 *   @path  $(CSLPATH)\example\fsync\fsync_counter_evt_gen\src
 *
 *   @desc configures counter event gen 10 and test if event gen is received correctly 
 *
 * ============================================================================
 */

#include <stdio.h>
//#include <soc.h>

#include <csl_fsync.h>
#include <csl_intc.h>
#include <constants.h>
//#include <val_util.h>



/****** Static variable declarations ***********/

// Intc objects
static CSL_IntcContext context;
static CSL_IntcEventHandlerRecord Record[13];

//Fsync interrupt object
static CSL_IntcObj intcFsync;
static CSL_IntcHandle hIntcFsync; 

//FSynnc objects
// handle for Fsync
static CSL_FsyncHandle hFsync;
//  Fsync object
static CSL_FsyncObj myFsyncObj;

static volatile Bool bRun = TRUE;   // boolean that indicating if testcase is complete

int testVal, count;
/******* Local function declarations ***********/

static void DoFsyncInitialization();

static void DoInterruptsInitialization();

static void interrupt fsync_event10_ISR();

static void fsync_counter_evt_gen();

/******* local function definitions **********/

static void DoFsyncInitialization()
{
   // Fsync setup 
   CSL_FsyncSetup myFsyncCfg;
   
   // terminal count setup 
   Uint16 terminalChipCount;
   CSL_FsyncTimerTermCountObj rp3TerminalCount, sysTerminalCount;
   CSL_FsyncTimerCountObj timerInit;

   // CSL status
   CSL_Status status;

   // ctrl arg for Hw command
   CSL_BitMask16 ctrlArg;
   
   // configuration obj for counter based trigger gen
   CSL_FsyncCounterTriggerGenObj configCounterTrigger;

   /* configure terminal count */
   terminalChipCount = CHIP_COUNT_WRAP_WCDMA_FDD;

   //rp3TerminalCount.lastFrameNum  = FRAME_COUNT_WRAP_WCDMA_FDD,
   rp3TerminalCount.lastSlotNum   = SLOT_COUNT_WRAP_WCDMA_FDD;
   rp3TerminalCount.lastSampleNum = SAMPLE_COUNT_WRAP_WCDMA_FDD;
   rp3TerminalCount.numChipTerminalCount = NUM_CHIP_COUNT_WRAP_WCDMA_FDD;
   rp3TerminalCount.pLastChipNum = &terminalChipCount;

   // sys timer not used, so set all fields to zero 
   sysTerminalCount.lastSlotNum   = 0;
   sysTerminalCount.lastSampleNum = 0;
   sysTerminalCount.numChipTerminalCount = 0,
   sysTerminalCount.pLastChipNum = NULL;
   
   /* Do config Fsync with non-RP1 interface, in this example UMTS_SYNC/UMTS_CLK drive the FSync */
   myFsyncCfg.syncRP3Timer = CSL_FSYNC_UMTS_SYNC;
   myFsyncCfg.syncSystemTimer = CSL_FSYNC_UMTS_SYNC;
   myFsyncCfg.clkRP3Timer = CSL_FSYNC_FRAME_SYNC_CLK;
   myFsyncCfg.clkSystemTimer = CSL_FSYNC_FRAME_SYNC_CLK;
   myFsyncCfg.pTerminalCountRP3Timer = &rp3TerminalCount;
   myFsyncCfg.pTerminalCountSystemTimer = &sysTerminalCount;
   myFsyncCfg.systemTimerRp1Sync = CSL_FSYNC_RP1_TYPE_NOT_USED;
   myFsyncCfg.rp3SyncDelay = 0;
   myFsyncCfg.systemSyncDelay = 0;
   myFsyncCfg.todSyncDelay = 0;
   myFsyncCfg.rp3EqualsSysTimer = FALSE;
   myFsyncCfg.syncMode = CSL_FSYNC_NON_RP1_SYNC_MODE;
   myFsyncCfg.reSyncMode = CSL_FSYNC_NO_AUTO_RESYNC_MODE;
   myFsyncCfg.crcUsage = CSL_FSYNC_USE_SYNC_BURST_ON_CRC_FAIL; // this field is don't care since FSync is in non-RP1 mode
   myFsyncCfg.crcPosition = CSL_FSYNC_CRC_BIT_16_RCVD_FIRST; // this field is don't care since FSync is in non-RP1 mode
   myFsyncCfg.todLeapUsage = CSL_FSYNC_DONT_ADD_LEAPSECS; // this field is don't care since FSync is in non-RP1 mode
   
   // watchdog timer is not set since we are using non-RP1 mode
   myFsyncCfg.setupWatchDog.rp3FrameUpdateRate   = 0; 
   myFsyncCfg.setupWatchDog.wcdmaFrameUpdateRate = 0; 
   myFsyncCfg.setupWatchDog.todFrameUpdateRate   = 0;

   timerInit.frameNum = 0;
   timerInit.slotNum = 0;
   //timerInit.chipTerminalIndex =0;
   timerInit.chipNum = 0;
   //timerInit.sampleNum = 0;
   
   // Init RP3 timer value
   myFsyncCfg.timerInit.pRp3TimerInit = &timerInit;          
   // Init system timer value
   myFsyncCfg.timerInit.pSystemTimerInit = &timerInit;         
   
    //configure counter based trigger event to occur every slot (2560 chips) for WCDMA(FDD)
   configCounterTrigger.timerUsed = CSL_FSYNC_RP3_TIMER;
   configCounterTrigger.eventGenUsed = CSL_FSYNC_TRIGGER_GEN_10;
   configCounterTrigger.eventCount = ((CHIP_COUNT_WRAP_WCDMA_FDD+1)*(SAMPLE_COUNT_WRAP_WCDMA_FDD+1)* (SLOT_COUNT_WRAP_WCDMA_FDD +1));

   configCounterTrigger.offset.slotOffset = 0;
   configCounterTrigger.offset.chipTerminalCountIndex = 0;
   configCounterTrigger.offset.chipOffset = 0;
   configCounterTrigger.offset.sampleOffset = 0;
   
   /* Initialize CSL library, this step is required */
   CSL_fsyncInit(NULL);

   /* Open handle for link 0 - for use */
   hFsync = CSL_fsyncOpen(&myFsyncObj, CSL_FSYNC, NULL, &status);

   if ((hFsync == NULL) || (status != CSL_SOK)) 
   {
      printf ("\nError opening CSL_FSYNC");
      exit(1);
   }                                                          

   // Do setup for Fsync
   CSL_fsyncHwSetup(hFsync, &myFsyncCfg);
   
   // configure counter based trigger generator 10
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_CONFIG_COUNTER_BASED_TRIGGER_GEN, (void *)&configCounterTrigger);
   // Enable trigger generator 10
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TRIGGER_GEN, (void *)&(configCounterTrigger.eventGenUsed));
   
   // Enable timer 
//   ctrlArg = CSL_FSYNC_RP3_TIMER_ENABLE | CSL_FSYNC_SYSTEM_TIMER_ENABLE | CSL_FSYNC_TOD_TIMER_ENABLE;
   ctrlArg = NULL;
   
   CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_ENABLE_TIMER, (void *)&ctrlArg);

   timer_doTest();  
}

/*********************************************************
 * Intc setup
 *
 ********************************************************/
static void DoInterruptsInitialization()
{
   CSL_IntcParam vectId1;
   CSL_IntcGlobalEnableState state;
   
   /* Setup the global Interrupt */
   context.numEvtEntries = 13;      //what this ??
   context.eventhandlerRecord = Record; 
   /* VectorID for the Global Edma Event  */
   vectId1 = CSL_INTC_VECTID_4;


   CSL_intcInit(&context);
   /* Enable NMIs  */
   CSL_intcGlobalNmiEnable();
   /* Enable Global Interrupts  */
   CSL_intcGlobalEnable(&state);
   
   /* Opening a handle for the FSync Event1 */
   hIntcFsync = CSL_intcOpen(&intcFsync,
                             CSL_INTC_EVENTID_FSEVT10, 
                             &vectId1,
                             NULL);
   
   //Hook the ISRs
   CSL_intcHookIsr(vectId1,&fsync_event10_ISR);
   
   // Clear the Interrupt    
   CSL_intcHwControl(hIntcFsync, CSL_INTC_CMD_EVTCLEAR, NULL);
     
    //Enable the Event & the interrupt 
   CSL_intcHwControl(hIntcFsync, CSL_INTC_CMD_EVTENABLE, NULL);
   
}

/*********************************************************
 * FSync Isr routine
 *
 ********************************************************/
static void interrupt fsync_event10_ISR()
{	
	static Uint32 count=0;	
   // query response
   CSL_FsyncTimerCountObj queryRp3TimerValue;
   //Disable the Event & the interrupt 
   CSL_intcHwControl(hIntcFsync, CSL_INTC_CMD_EVTDISABLE, NULL);
     
   // Read value of RP3 timer 
   CSL_fsyncGetHwStatus(hFsync, CSL_FSYNC_QUERY_RP3_TIMER_VALUE, (void *)&queryRp3TimerValue);   // rp3 timer val is slot =1
   
   if(count == 1)
   {
   		printf("Frame value = %d\n",queryRp3TimerValue.frameNum);
   		printf("slot value = %d\n",queryRp3TimerValue.slotNum);
   		if (queryRp3TimerValue.frameNum == 1 && queryRp3TimerValue.slotNum==0)
   		{
      		printf("Fsync counter event generation test successful\n");
	  		printf("FSYNC: TEST PASSED\n");
   		}
   		else
   		{
      		printf("Fsync counter event generation test failed\n");
	  		printf("FSYNC: TEST FAILED\n");
   		}
		// disable timers 
   		CSL_fsyncHwControl(hFsync, CSL_FSYNC_CMD_DISABLE_TIMER, NULL);

   		//close fsync handle
   		CSL_fsyncClose(hFsync); 
    
    	bRun = FALSE;
   	}
	//Enable the Event & the interrupt 
    CSL_intcHwControl(hIntcFsync, CSL_INTC_CMD_EVTENABLE, NULL);
  	count++;

}




/****** Public fn definitions ***************/

void fsync_counter_evt_gen()
{
   
   printf("Executing Fsync counter event generation test \n");

   DoInterruptsInitialization();

   DoFsyncInitialization();
   
   while(bRun)    // After everything's done sit in interruptable while loop
            // while not servicing an interrupt.
   {
      asm(" NOP 5 " ); 
      asm(" NOP 5 " ); 
   }
   
   

}

/****** Public fn definitions ***************/

void main()
{
   fsync_counter_evt_gen(); // checks operation of counter event gen 1
   
}

