/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/*
 *  14-Jan-2009 removed tmrIpGateHi, tmrClksrcHi, tmrInvInpHi references
 */

#include <csl_tmr.h>

CSL_TmrHandle    hTmr;
CSL_TmrObj       TmrObj;
CSL_TmrHwSetup   TmrSetup;

Bool interruptFlag[] = {
    FALSE,                    // TIMER0Lo_GPT0 Flag
    FALSE,                    // TIMER0Hi_GPT0 Flag
};

//Flag to indicate runtime status and the number of times it fails.
Uint32 failFlag = 0;
Uint32 timercnt = 0;

void timer_doTest(void)
{
	Uint32 prdLo = 0x00000145;
    Uint32 prdHi = 0x00000000;
    Uint32 cntLo = 0x00000000; 
    Uint32 cntHi = 0x00000000; 
    CSL_Status status;

    CSL_TmrEnamode	 tmrMode = CSL_TMR_ENAMODE_ENABLE;
    //Uint32 *TmrLo;


	// Module Initialization
    CSL_tmrInit(NULL);

    //Open Handle 
    hTmr = CSL_tmrOpen(&TmrObj,0,NULL,&status);
	if (status != CSL_SOK)
	{
		printf("Timer open error\n");
		exit(1);
	}

    CSL_tmrHwControl(hTmr,CSL_TMR_CMD_RESET_TIMLO,NULL);
    CSL_tmrHwControl(hTmr,CSL_TMR_CMD_RESET_TIMHI,NULL);

    /*------------------------------------------------------------------*/
    /* Timer Dual 64-bit GP Onetime Mode Test				*/
    /*------------------------------------------------------------------*/    

    /*------------------------------------------------------------------*/
    /* Configuring timer0 for 64-bit GP Mode		 		*/
    /*------------------------------------------------------------------*/
    CSL_tmrGetHwSetup(hTmr, &TmrSetup);

    TmrSetup.tmrClksrcLo       = CSL_TMR_CLKSRC_INTERNAL;
    TmrSetup.tmrClockPulseLo   = CSL_TMR_CP_CLOCK;
	TmrSetup.tmrInvInpLo       = CSL_TMR_INVINP_INVERTED;
	TmrSetup.tmrInvOutpLo      = CSL_TMR_INVOUTP_INVERTED;
	TmrSetup.tmrIpGateLo       = CSL_TMR_CLOCK_INP_NOGATE;
    TmrSetup.tmrPulseWidthLo   = CSL_TMR_PWID_THREECLKS;
    TmrSetup.tmrTimerPeriodLo  = prdLo;
    TmrSetup.tmrClockPulseHi   = CSL_TMR_CP_CLOCK;
	TmrSetup.tmrInvOutpHi      = CSL_TMR_INVOUTP_INVERTED;
    TmrSetup.tmrPulseWidthHi   = CSL_TMR_PWID_THREECLKS;
    TmrSetup.tmrTimerPeriodHi  = prdHi;

    TmrSetup.tmrTimerMode      = CSL_TMR_TIMMODE_GPT;
 
    /*------------------------------------------------------------------*/
    /* Set count to 0							*/
    /*------------------------------------------------------------------*/
    TmrSetup.tmrTimerCounterLo     = cntLo;
    TmrSetup.tmrTimerCounterHi     = cntHi;
    CSL_tmrHwSetup(hTmr,&TmrSetup);
           
    /*------------------------------------------------------------------*/
    /* Start timer in oneshot mode                                   */
    /*------------------------------------------------------------------*/    
	CSL_tmrHwControl(hTmr,CSL_TMR_CMD_START64,&tmrMode);
}
