/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
#ifndef _CONSTANTS_H_
#define _CONSTANTS_H_

//#include <csl_aif.h>

// 3GPP constants

#define FRAME_COUNT_WRAP_WCDMA_FDD  4095
#define NUM_CHIP_COUNT_WRAP_WCDMA_FDD  1
#if QT
#ifdef SHORT_FRAME_MODE
#define SLOT_COUNT_WRAP_WCDMA_FDD   9
#define SAMPLE_COUNT_WRAP_WCDMA_FDD 31
#define CHIP_COUNT_WRAP_WCDMA_FDD   15
#else                            
#define SLOT_COUNT_WRAP_WCDMA_FDD   14
#define SAMPLE_COUNT_WRAP_WCDMA_FDD 31
#define CHIP_COUNT_WRAP_WCDMA_FDD   2559
#endif
#else
#ifdef SHORT_FRAME_MODE
#define SLOT_COUNT_WRAP_WCDMA_FDD   9
#define SAMPLE_COUNT_WRAP_WCDMA_FDD 7
#define CHIP_COUNT_WRAP_WCDMA_FDD   15
#else                            
#define SLOT_COUNT_WRAP_WCDMA_FDD   14
#define SAMPLE_COUNT_WRAP_WCDMA_FDD 7
#define CHIP_COUNT_WRAP_WCDMA_FDD   2559
#endif 
#endif

#define NUM_CHIPS_PER_FRAME         ((SLOT_COUNT_WRAP_WCDMA_FDD+1)*(CHIP_COUNT_WRAP_WCDMA_FDD+1))

// OBSAI, CPRI, other constants

#define BYTES_PER_QUADWORD          16
#define BYTES_PER_WORD              4

#define UL_OSF                      2 // UL oversampling factor

// fsync constants
#define FSYNC_NUM_ACTIVE_MASK_EVEN_GEN       15
#define FSYNC_NUM_ACTIVE_COUNTER_EVEN_GEN    1
#define SYNC_BURST_RP3_FRAME_UPDATE_RATE     15
#define SYNC_BURST_WCDMA_FRAME_UPDATE_RATE   15
#define SYNC_BURST_TOD_FRAME_UPDATE_RATE     15

// test harness constants

#define WORDS_PER_CTRL_MSG                   (8) // ctrl msg is 19 bytes, allocate 32 bytes for ctrl msg storage

#define AXS_CHIPS_PER_INBND_EDMA_XFER        4 // DL 4, UL 8
#define AXS_CHIPS_PER_OUTBND_EDMA_XFER       4 // DL 4, UL 8

#define BYTES_PER_INBND_CHIP                 4 // DL 4, UL 4 
#define BYTES_PER_OUTBND_CHIP                4 // DL 4, UL 4

#define BYTES_PER_CTRL_MSG                   (WORDS_PER_CTRL_MSG*BYTES_PER_WORD)

#define NUM_AXS_INBND_LINK_0                 16
#define NUM_AXS_OUTBND_LINK_0                16    

#define WORDS_PER_INBND_CHIP                 (BYTES_PER_INBND_CHIP/BYTES_PER_WORD)
#define WORDS_PER_OUTBND_CHIP                (BYTES_PER_OUTBND_CHIP/BYTES_PER_WORD)

#define NUM_CHIPS_PER_CTRL_MSG               20 // this is constant regardless of link rate
#define NUM_CTRL_MSG_PER_FRAME               (NUM_CHIPS_PER_FRAME/NUM_CHIPS_PER_CTRL_MSG)

#define SIZE_INBND_CS_BUFFER_IN_WORDS        (NUM_CHIPS_PER_FRAME*WORDS_PER_INBND_CHIP*NUM_AXS_INBND_LINK_0)
#define SIZE_INBND_PS_BUFFER_IN_WORDS        (NUM_CTRL_MSG_PER_FRAME*WORDS_PER_CTRL_MSG)

#define SIZE_OUTBND_CS_BUFFER_IN_WORDS       (NUM_CHIPS_PER_FRAME*WORDS_PER_OUTBND_CHIP*NUM_AXS_OUTBND_LINK_0)   
#define SIZE_OUTBND_PS_BUFFER_IN_WORDS       (NUM_CTRL_MSG_PER_FRAME*WORDS_PER_CTRL_MSG)  


#define LENGTH_TEST_RUN_IN_CHIPS             (4*NUM_CHIPS_PER_FRAME) // inbound data takes 3 frames to arrive at RxMAC in loopback

// INTC Params
#define NUM_CPU_EVENTS              3

// INTC handle index
#define CPU_EVT_EDMA_TCC            0
#define CPU_EVT_FS_1                1
#define CPU_EVT_FS_4                2


// AIF setup constans

#define AIF_NUM_ACTIVE_LINKS                1
#define AIF_NUM_TYPE_FIELD_ENTRIES          3
#define AIF_NUM_ACTIVE_AXS_INBND_LINK_0     16
#define AIF_NUM_ACTIVE_AXS_OUTBND_LINK_0    16


// inbound PS FIFO config
#define AIF_NUM_ACTIVE_INBND_PS_FIFOS     1
#define AIF_SIZE_INBND_PS_ADDR_FIFO_0     1
#define AIF_SIZE_INBND_PS_ADDR_FIFO_1     0
#define AIF_SIZE_INBND_PS_ADDR_FIFO_2     0
#define AIF_SIZE_INBND_PS_ADDR_FIFO_3     0

#define AIF_MAX_SIZE_INBND_PS_ADDR_FIFO   1 // max size of inbound PS fifo (should be largest fifo0,fifo1..fifo3 size)

#define AIF_EVTDEPTH_INBND_PS_FIFO_0    (CSL_AIF_INBOUND_PS_FIFO_EVENT_DEPTH_2)
#define AIF_EVTDEPTH_INBND_PS_FIFO_1    (CSL_AIF_INBOUND_PS_FIFO_EVENT_DEPTH_2)
#define AIF_EVTDEPTH_INBND_PS_FIFO_2    (CSL_AIF_INBOUND_PS_FIFO_EVENT_DEPTH_2)
#define AIF_EVTDEPTH_INBND_PS_FIFO_3    (CSL_AIF_INBOUND_PS_FIFO_EVENT_DEPTH_2)

#define AIF_SIZE_INBND_FIFO_0           1 // AIF translates this as size of fifo 0 = 1*16 = 16 quadwords (i.e. 16 OBSAI msg payloads)          
#define AIF_SIZE_INBND_FIFO_1           1
#define AIF_SIZE_INBND_FIFO_2           1
#define AIF_SIZE_INBND_FIFO_3           1

#define AIF_INBOUND_CS_RAM_LINK_0       0xA0000000
#define AIF_INBOUND_CS_RAM_LINK_1       0xA0400000
#define AIF_INBOUND_CS_RAM_LINK_2       0xA0800000
#define AIF_INBOUND_CS_RAM_LINK_3       0xA0C00000
#define AIF_INBOUND_CS_RAM_LINK_4       0xA1000000
#define AIF_INBOUND_CS_RAM_LINK_5       0xA1400000

#define AIF_ADDR_IN_PS_FIFO_0           0xA4000000
#define AIF_ADDR_IN_PS_FIFO_1           0xA4400000
#define AIF_ADDR_IN_PS_FIFO_2           0xA4800000
#define AIF_ADDR_IN_PS_FIFO_3           0xA4C00000

#define AIF_OUTBOUND_CS_RAM_LINK_0      0xA2000000
#define AIF_OUTBOUND_CS_RAM_LINK_1      0xA2400000
#define AIF_OUTBOUND_CS_RAM_LINK_2      0xA2800000
#define AIF_OUTBOUND_CS_RAM_LINK_3      0xA2C00000
#define AIF_OUTBOUND_CS_RAM_LINK_4      0xA3000000
#define AIF_OUTBOUND_CS_RAM_LINK_5      0xA3400000

#define AIF_OUTBND_PS_FIFO_0            0xA5000000
#define AIF_OUTBND_PS_FIFO_1            0xA5080000
#define AIF_OUTBND_PS_FIFO_2            0xA5100000
#define AIF_OUTBND_PS_FIFO_3            0xA5180000
#define AIF_OUTBND_PS_FIFO_4            0xA5200000
#define AIF_OUTBND_PS_FIFO_5            0xA5280000
#define AIF_OUTBND_PS_FIFO_6            0xA5300000
#define AIF_OUTBND_PS_FIFO_7            0xA5380000
#define AIF_OUTBND_PS_FIFO_8            0xA5400000
#define AIF_OUTBND_PS_FIFO_9            0xA5480000
#define AIF_OUTBND_PS_FIFO_10           0xA5500000
#define AIF_OUTBND_PS_FIFO_11           0xA5580000
#define AIF_OUTBND_PS_FIFO_12           0xA5600000
#define AIF_OUTBND_PS_FIFO_13           0xA5680000
#define AIF_OUTBND_PS_FIFO_14           0xA5700000
#define AIF_OUTBND_PS_FIFO_15           0xA5780000
#define AIF_OUTBND_PS_FIFO_16           0xA5800000
#define AIF_OUTBND_PS_FIFO_17           0xA5880000
#define AIF_OUTBND_PS_FIFO_18           0xA5900000
#define AIF_OUTBND_PS_FIFO_19           0xA5980000
#define AIF_OUTBND_PS_FIFO_20           0xA5A00000
#define AIF_OUTBND_PS_FIFO_21           0xA5A80000
#define AIF_OUTBND_PS_FIFO_22           0xA5B00000
#define AIF_OUTBND_PS_FIFO_23           0xA5B80000
#define AIF_OUTBND_PS_FIFO_24           0xA5C00000
#define AIF_OUTBND_PS_FIFO_25           0xA5C80000
#define AIF_OUTBND_PS_FIFO_26           0xA5D00000
#define AIF_OUTBND_PS_FIFO_27           0xA5D80000
#define AIF_OUTBND_PS_FIFO_28           0xA5E00000
#define AIF_OUTBND_PS_FIFO_29           0xA5E80000


// outbound constants
#define AIF_TM_FIFO_THRESH              (8)
#define AIF_TM_DELTA_OFFSET             (200) // in byte clks

#define AIF_PE_AXC_TYPE_OUTBOUND        (2)

#define AIF_PE_PS_DATA_MASK             CSL_AIF_PE_INVALID_PS_DATA_MASK
#define AIF_PE_PS_DATA_COMPARE          CSL_AIF_PE_INVALID_COMPARE
#define AIF_PE_PS_DATA_SRC_SEL          CSL_AIF_OUT_PS_FIFO_0
#define AIF_PE_PS_DATA_AGGR_CTRL        CSL_AIF_PE_AGGR_CTRL_NOP

/** Outbound FIFO enable mask for link 0 */
#define AIF_DB_OUT_FIFO_ENABLE_MASK_LINK_0            (0x1) // enable fifo 0 

// inbound constants
#define AIF_RM_FRAME_SYNC_THRESH    (3)
#define AIF_RM_FRAME_UNSYNC_THRESH  (3)
#define AIF_RM_SYNC_THRESH          (3)
#define AIF_RM_UNSYNC_THRESH        (3)

#define AIF_RM_PI_OFFSET                    (200)      // in vbus clks
#define AIF_RM_VALID_MASTER_FRAME_OFFSET    (200)      // in vbus clks
#define AIF_RM_MAX_MASTER_FRAME_OFFSET      (200)      // in vbus clks
#define AIF_RM_LOS_DETECT_THREH             (255)


// AIF look tables 

#define AIF_TYPE_FIELD_LUT {CSL_AIF_PD_OBSAI_TYPE_VALUE_PKT_SW,CSL_AIF_PD_OBSAI_TYPE_VALUE_INACTIVE,CSL_AIF_PD_OBSAI_TYPE_VALUE_CIR_SW}

#define AIF_AXC_ADDR_IN_LUT_LINK_0 \
{  \
0x0,  \
0x1,  \
0x2,  \
0x3,  \
0x4,  \
0x5,  \
0x6,  \
0x7,  \
0x8,  \
0x9,  \
0xA,  \
0xB,  \
0xC,  \
0xD,  \
0xE,  \
0xF   \
}

#define AIF_PS_ADDR_LUT_FIFO_0 \
{     \
0x40  \
}

// outbound addr lut for link 0
#define AIF_AXC_ADDR_OUT_LUT_LINK_0 \
{     \
0x0,  \
0x1,  \
0x2,  \
0x3,  \
0x4,  \
0x5,  \
0x6,  \
0x7,  \
0x8,  \
0x9,  \
0xA,  \
0xB,  \
0xC,  \
0xD,  \
0xE,  \
0xF   \
}

// outbound lut for axc masks for link 0
#define AIF_AXC_OUT_MASK_LINK_0 \
{     \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF,  \
0xF   \
}

// outbound lut for axc compare values for link 0
#define AIF_AXC_OUT_COMP_LINK_0 \
{     \
0x0,  \
0x1,  \
0x2,  \
0x3,  \
0x4,  \
0x5,  \
0x6,  \
0x7,  \
0x8,  \
0x9,  \
0xA,  \
0xB,  \
0xC,  \
0xD,  \
0xE,  \
0xF   \
}

// outbound lut for axc aggregator ctrl values for link 0
#define AIF_AXC_OUT_AGGRCTRL_LINK_0 \
{     \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT,  \
CSL_AIF_PE_AGGR_CTRL_ADD_15_16_BIT   \
}

// outbound lut for ctrl data terminal count values for link 0
#define AIF_CTRL_TCOUNT_LINK_0 \
{     \
1,    \
0,    \
0,    \
0     \
}

// outbound lut for ctrl data compare values for link 0
#define AIF_CTRL_COMPARE_LINK_0 \
{     \
0,    \
0,    \
0,    \
0     \
}

// outbound lut for ctrl data src select values for link 0
#define AIF_CTRL_SRC_SEL_LINK_0 \
{     \
CSL_AIF_OUT_PS_FIFO_0,  \
CSL_AIF_OUT_PS_FIFO_0,  \
CSL_AIF_OUT_PS_FIFO_0,  \
CSL_AIF_OUT_PS_FIFO_0   \
}

// aggr ctrl for ctrl data for link 0
#define AIF_CTRL_OUT_AGGRCTRL_LINK_0 \
{     \
CSL_AIF_PE_AGGR_CTRL_INSERT,  \
CSL_AIF_PE_AGGR_CTRL_NOP,     \
CSL_AIF_PE_AGGR_CTRL_NOP,     \
CSL_AIF_PE_AGGR_CTRL_NOP      \
}

// EDMA Params
#define NUM_EDMA_CHANNELS     4

// EDMA handle index
#define EDMA_HNDL_AIF_EXTMEM_CS_LINK_0             0
#define EDMA_HNDL_AIF_PSFIFO_0_EXTMEM              1
#define EDMA_HNDL_EXTMEM_AIF_CS_LINK_0             2
#define EDMA_HNDL_EXTMEM_AIF_PSFIFO_0              3

// EDMA ch entries
#define EDMA_CH_AIF_EXTMEM_CS_LINK_0      CSL_EDMA3_CHA_FSEVT4   //16 
#define EDMA_CH_AIF_PSFIFO_0_EXTMEM       CSL_EDMA3_CHA_AIF_PSEVT1 // 40
#define EDMA_CH_EXTMEM_AIF_CS_LINK_0      CSL_EDMA3_CHA_FSEVT5 // 17
#define EDMA_CH_EXTMEM_AIF_PSFIFO_0       CSL_EDMA3_CHA_FSEVT10 // 22          

// EDMA tcc codes
#define EDMA_TCC_AIF_EXTMEM_CS_LINK_0              CSL_EDMA3_CHA_FSEVT4  // 16
#define EDMA_TCC_AIF_PSFIFO_0_EXTMEM               CSL_EDMA3_CHA_AIF_PSEVT1 // 40
#define EDMA_TCC_EXTMEM_AIF_CS_LINK_0              CSL_EDMA3_CHA_FSEVT5 // 17
#define EDMA_TCC_EXTMEM_AIF_PSFIFO_0               CSL_EDMA3_CHA_FSEVT10 // 22

// EDMA PaRAM entry index
#define EDMA_PARAM_EXTMEM_AIF_CS_LINK_0            2
#define EDMA_PARAM_EXTMEM_AIF_CS_LINK_0_RELOAD     3
#define EDMA_PARAM_EXTMEM_AIF_PSFIFO_0             4
#define EDMA_PARAM_EXTMEM_AIF_PSFIFO_0_RELOAD      5
#define EDMA_PARAM_AIF_EXTMEM_CS_LINK_0            62
#define EDMA_PARAM_AIF_EXTMEM_CS_LINK_0_RELOAD     63
#define EDMA_PARAM_AIF_PSFIFO_0_EXTMEM             40
#define EDMA_PARAM_AIF_PSFIFO_0_EXTMEM_RELOAD      41


// AIF CS RAM -> Ext Mem EDMA Params
#define A_CNT_AIF_EXTMEM_CS_XFER       16  
#define B_CNT_AIF_EXTMEM_CS_XFER       (NUM_AXS_INBND_LINK_0) // DL NUM_AXS_INBND_LINK_0, UL NUM_AXS_INBND_LINK_0*UL*OSF 
#define C_CNT_AIF_EXTMEM_CS_XFER       (NUM_CHIPS_PER_FRAME/AXS_CHIPS_PER_INBND_EDMA_XFER)                                   
#define SBIDX_AIF_EXTMEM_CS_XFER       16  
#define DBIDX_AIF_EXTMEM_CS_XFER       16
#define SCIDX_AIF_EXTMEM_CS_XFER       256 // DL 256, UL 512
#define DCIDX_AIF_EXTMEM_CS_XFER       (NUM_AXS_INBND_LINK_0*AXS_CHIPS_PER_INBND_EDMA_XFER*BYTES_PER_INBND_CHIP) // DL.., UL.. *UL_OSF 

// AIF PS FIF0 0 -> Ext Mem EDMA Params
#define A_CNT_AIF_FIFO_0_EXTMEM_XFER    BYTES_PER_CTRL_MSG // length of OBSAI ctrl/ps message
#define B_CNT_AIF_FIFO_0_EXTMEM_XFER    2  // event depth
#define C_CNT_AIF_FIFO_0_EXTMEM_XFER    (NUM_CTRL_MSG_PER_FRAME/B_CNT_AIF_FIFO_0_EXTMEM_XFER)
#define SBIDX_AIF_FIFO_0_EXTMEM_XFER    0
#define DBIDX_AIF_FIFO_0_EXTMEM_XFER    (A_CNT_AIF_FIFO_0_EXTMEM_XFER)
#define SCIDX_AIF_FIFO_0_EXTMEM_XFER    0
#define DCIDX_AIF_FIFO_0_EXTMEM_XFER    (B_CNT_AIF_FIFO_0_EXTMEM_XFER*A_CNT_AIF_FIFO_0_EXTMEM_XFER)

// Ext Mem -> AIF CS RAM
#define A_CNT_EXTMEM_AIF_CS_XFER        16
#define B_CNT_EXTMEM_AIF_CS_XFER        (NUM_AXS_OUTBND_LINK_0) // DL NUM_AXS_OUTBND_LINK_0, UL NUM_AXS_OUTBND_LINK_0*UL_OSF
#define C_CNT_EXTMEM_AIF_CS_XFER        (NUM_CHIPS_PER_FRAME/AXS_CHIPS_PER_INBND_EDMA_XFER)
#define SBIDX_EXTMEM_AIF_CS_XFER        16
#define DBIDX_EXTMEM_AIF_CS_XFER        16
#define SCIDX_EXTMEM_AIF_CS_XFER        (NUM_AXS_OUTBND_LINK_0*AXS_CHIPS_PER_OUTBND_EDMA_XFER*BYTES_PER_OUTBND_CHIP) // DL.., UL ..*UL_OSF
#define DCIDX_EXTMEM_AIF_CS_XFER        256 // DL 256, UL 512

// Ext Mem -> AIF FIFO 0 EDMA Params
#define A_CNT_EXTMEM_AIF_FIFO_0_XFER    BYTES_PER_CTRL_MSG
#define B_CNT_EXTMEM_AIF_FIFO_0_XFER    (1)
#define C_CNT_EXTMEM_AIF_FIFO_0_XFER    (NUM_CHIPS_PER_FRAME/AXS_CHIPS_PER_INBND_EDMA_XFER)
#define SBIDX_EXTMEM_AIF_FIFO_0_XFER    0
#define DBIDX_EXTMEM_AIF_FIFO_0_XFER    0
#define SCIDX_EXTMEM_AIF_FIFO_0_XFER    BYTES_PER_CTRL_MSG
#define DCIDX_EXTMEM_AIF_FIFO_0_XFER    0

#endif

