/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ===========================================================================
 *   @file  csl_aifGetBaseAddress.c
 *
 *   @brief File for functional layer of CSL API  CSL_aifGetBaseAddress () 
 *
 *   @path  $(CSLPATH)\src\common
 *
 *   @desc  The  CSL_aifGetBaseAddress  function definition.
 */
/* =============================================================================
 * Revision History
 * ===============
 *  07-Mar-2006 NS updated the file for DOXYGEN compatibiliy
 *
 * =============================================================================
 */
#include <csl_aif.h>

/** ============================================================================
 *   @n@b CSL_bwmngmtGetBaseAddress
 *
 *   @b Description
 *   @n  Function to get the base address of the peripheral instance.
 *       This function is used for getting the base address of the peripheral
 *       instance. This function will be called inside the CSL_bwmngmtOpen()
 *       function call. This function is open for re-implementing if the user
 *       wants to modify the base address of the peripheral object to point to
 *       a different location and there by allow CSL initiated write/reads into
 *       peripheral. MMR's go to an alternate location.
 *
 *   @b Arguments
 *   @verbatim
            bwmngmtNum        Specifies the instance of the bwmngmt to be opened.

            pBwmngmtParam     Module specific parameters.

            pBaseAddress      Pointer to baseaddress structure containing base
                              address details.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK            Successful on getting the base 
 *                                             address of bwmngmt
 *   @li                    CSL_ESYS_FAIL      The instance number is invalid.
 *   @li                    CSL_ESYS_INVPARAMS Inavlid parameters 
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Base Address structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable
 *
 *         2. Base address structure is modified.
 *
 *   @b Example
 *   @verbatim
        CSL_Status              status;
        CSL_BwmngmtBaseAddress  baseAddress;

       ...
      status = CSL_bwmngmtGetBaseAddress(CSL_BWMNGMT, NULL, &baseAddress);

     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_aifGetBaseAddress, ".text:csl_section:aif");
 
CSL_Status
CSL_aifGetBaseAddress (
        CSL_InstNum 	        aifNum,
        CSL_AifParam *          paifParam,
        CSL_AifBaseAddress *    pBaseAddress 
)
{
    CSL_Status st = CSL_SOK;
    if (pBaseAddress == NULL) {
        return CSL_ESYS_INVPARAMS;
    }

    switch (aifNum){
    case CSL_AIF:
        pBaseAddress->regs = (CSL_AifRegsOvly)CSL_AIF_0_REGS;
        break;
    default:
        pBaseAddress->regs = (CSL_AifRegsOvly)NULL;
        st = CSL_ESYS_FAIL;
        break;
    }

    return st;
}

