/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * ============================================================================
 */

/** ===========================================================================
 * @file csl_pscClose.c
 *
 * @brief File for functional layer of CSL API CSL_pscClose()
 *
 * @path $(CSLPATH)\src\psc
 *
 * @desc The CSL_pscClose() function definition & it's associated
 *       functions
 * ============================================================================
 */

/* ============================================================================
 * Revision History
 * ===============
 * 29-Jun-2006 TRR File Created.
 * ============================================================================
 */

#include <csl_psc.h>

/** ============================================================================
 *   @n@b CSL_pscClose.c
 *
 *   @b Description
 *   @n This function marks that CSL for the PSC instance is closed.
 *      CSL for the PSC instance need to be reopened before using any
 *      PSC CSL API.
 *
 *   @b Arguments
 *   @verbatim
            hPsc   Pointer to the object that holds reference to the
                   instance of PSC requested after the call 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK            - PSC is closed
 *                                               successfully
 *
 *   @li                    CSL_ESYS_BADHANDLE - The handle passed is invalid
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_pscInit() and CSL_pscOpen() must be called successfully in order before calling CSL_pscClose(). 
 *
 *   <b> Post Condition </b>
 *   @n  1. The PSC CSL APIs can not be called until the PSC
 *          CSL is reopened again using CSL_pscOpen()
 *
 *   @b Modifies
 *   @n  Obj structure values for the instance 
 *
 *   @b Example
 *   @verbatim
           CSL_PscHandle           hPsc;
           ...
           CSL_pscClose(hPsc);
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_pscClose, ".text:csl_section:psc");
CSL_Status CSL_pscClose (
    CSL_PscHandle hPsc
)
{
    CSL_Status st;

    if (hPsc != NULL) {
        hPsc->regs = (CSL_PscRegsOvly)NULL;
        hPsc->perNum = (CSL_InstNum)-1;

        st = CSL_SOK;
    }
    else {
        st = CSL_ESYS_BADHANDLE;
    }

    return st;
}

