/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * ============================================================================
 */

/** ===========================================================================
 *  @file csl_pwrdwnGetHwSetup.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pwrdwnGetHwSetup()
 *
 *  @path $(CSLPATH)\pwrdwn\src
 *
 *  @Desc The @a CSL_pwrdwnGetHwSetup() function definition & it's associated
 *        functions
 *
 *  Modification 1
 *    - Modified on: 7/16/2004
 *    - Reason: created the sources
 *
 *  @author Ruchika Kharwar.
 * ============================================================================
 */

#include <csl_pwrdwn.h>

/** ===========================================================================
 *   @n@b CSL_pwrdwnGetHwSetup
 *
 *   @b Description
 *   @n It retrives the hardware setup parameters. Not Implemented. For future use.
 *
 *   @b Arguments
 *   @verbatim
         hPwr        Handle to the PWRDWN instance

         hwSetup     Pointer to hardware setup structure
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Always returns
 *
 *   <b> Pre Condition </b>
 *   @b CSL_pwrdwnInit(), CSL_pwrdwnOpen() must be opened prior to this call.
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n None
 *   
 *   @b Example
     @verbatim
       CSL_PwrdwnObj pwrObj;
       CSL_PwrdwnHwSetup pwrSetup, querySetup;
       CSL_PwrdwnHandle hPwr;
       // Init Module
       ...
       if (CSL_pwrdwnInit(NULL) != CSL_SOK)
           exit;
           // Opening a handle for the Module	
           hPwr = CSL_pwrdwnOpen (&pwrObj, CSL_PWRDWN, NULL, NULL);
	
	   // Setup the arguments for the Setup structure
	   ...
	
	   // Setup
	   CSL_pwrdwnHwSetup(hPwr,&pwrSetup);
    
       // Query Setup
       CSL_pwrdwnGetHwSetup(hPwr,&querySetup);
	
       // Close handle
       CSL_pwrdwnClose(hPwr);

     @endverbatim
 * ============================================================================
 */
#pragma CODE_SECTION (CSL_pwrdwnGetHwSetup, ".text:csl_section:pwrdwn");
CSL_Status CSL_pwrdwnGetHwSetup (
	/* Pointer to the object that holds reference to the
     * instance of PWRDWN.
	 */
    CSL_PwrdwnHandle  hPwrdwn,

    /* Pointer to setup structure which contains the
	 * information to program PWRDWN to a useful state 
	 */
    CSL_PwrdwnHwSetup *setup
)
{ 
	return CSL_SOK;
}

